@@ -17,7 +17,7 @@ void capture::captureWidget(QWidget *base)
    if(!pixmap->save(auxName,format.ascii()))
    {
       QString s;
-      s = i18n("Can't save image to file:/n%1").arg(auxName);
+      s = i18n("Unable to save image to file: %1").arg(auxName);
       KMessageBox::sorry(0L, s);
    }
    counter++;
