@@ -60,20 +60,20 @@ Principal::Principal( const char *name)
         menu->insertItem(i18n("Video information"),this,SLOT(click_info()) );
         menu->insertSeparator();
         menu->insertItem(SmallIconSet("fileopen"),
-                         i18n("Open file..."),this,SLOT(click_open()) );
+                         i18n("Open File..."),this,SLOT(click_open()) );
         menu->insertItem(SmallIconSet("configure"),
                          i18n("Setup..."),this,SLOT(click_config()) );
         menu->insertSeparator();
         menu->insertItem(SmallIconSet("original"),
-                         i18n("Original size"),this,SLOT(click_original()) );
+                         i18n("Original Size"),this,SLOT(click_original()) );
         menu->insertItem(SmallIconSet("half"),
-                         i18n("Half size"),this,SLOT(click_half()) );
+                         i18n("Half Size"),this,SLOT(click_half()) );
         menu->insertItem(SmallIconSet("double"),
-                         i18n("Double size"),this,SLOT(click_double()) );
+                         i18n("Double Size"),this,SLOT(click_double()) );
         menu->insertItem(SmallIconSet("ak_maximize"),
                          i18n("Maximized"),this,SLOT(maximize()) );
         menuItemFullScreen = menu->insertItem(SmallIconSet("fullscreen"),
-                         i18n("Full screen"),this,SLOT(goFullScreen()) );
+                         i18n("Full Screen"),this,SLOT(goFullScreen()) );
 
 #ifdef XF86_VM
         videoMode=new aktionVm(mainwidget);
@@ -343,7 +343,7 @@ void Principal::click_open()
         					     "*.mpg *.MPG *.mpeg *.MPEG|MPG Files (*.mpg)\n"
         					     "*.fli *.FLI *.flc *.FLC|FLI,FLC Files (*.fli *.flc)\n"
         					     "*|All Files (*)\n")
-        				      ,0L,i18n("Select a movie"));
+        				      ,0L,i18n("Select Movie"));
       if (url.isEmpty()) return;
     }
     else
@@ -378,7 +378,7 @@ void Principal::click_open()
 	  }
 
 	  whatToDo=CONTINUE_LOADING;
-	  kapp->setOverrideCursor( waitCursor );
+          QApplication::setOverrideCursor( waitCursor );
 	  setParameters();
 	  parametersChanged=false;
 	  video->setFile(fileName);
@@ -407,10 +407,14 @@ void Principal::continueLoading()
 
        theCapturer.resetCounter();
        config->setGroup("capture");
-       theCapturer.setParameters(config->readEntry("outputDir"),fileName,
+       
+       QString dir =  config->readEntry("outputDir","~");
+       if ( dir == "~")
+             dir = QDir::homeDirPath();
+       theCapturer.setParameters(dir,fileName,
                                  config->readEntry("outputFormat"));
 
-       kapp->restoreOverrideCursor();
+       QApplication::restoreOverrideCursor();
        changeInitialSize();
        click_play();
    }
@@ -419,7 +423,7 @@ void Principal::continueLoading()
        /* something is wrong... */
        /* disable buttons */
        toggleButtons(false);
-       kapp->restoreOverrideCursor();
+       QApplication::restoreOverrideCursor();
        KMessageBox::sorry(0L,video->getErrorString());
    }
    fileName="";
@@ -515,7 +519,11 @@ void Principal::click_config()
       parametersChanged=true;
 
       config->setGroup("capture");
-      theCapturer.setParameters(config->readEntry("outputDir"),fileName,
+      QString dir =  config->readEntry("outputDir","~");
+      if ( dir == "~")
+             dir = QDir::homeDirPath();
+
+      theCapturer.setParameters(dir,fileName,
                                 config->readEntry("outputFormat"));
 
       config->setGroup("others");
@@ -791,7 +799,7 @@ void Principal::goFullScreen()
    config->setGroup("scaling");
    if (config->readBoolEntry("grabmouse"))
    {
-      kapp->setOverrideCursor( blankCursor );
+      QApplication::setOverrideCursor( blankCursor );
       QCursor::setPos(0,0);
    }
 
@@ -835,7 +843,7 @@ void Principal::undoFullScreen()
 
    config->setGroup("scaling");
    if (config->readBoolEntry("grabmouse"))
-      kapp->restoreOverrideCursor();
+      QApplication::restoreOverrideCursor();
 
 //   KWM::setDecoration( winId(), KWM::normalDecoration );
 
