@@ -93,7 +93,7 @@ protected:
 	int numQueuedPaths;
 
 	// pseudo random table for fast "random" decisions
-	static const int PRSIZE = 16;
+	enum { PRSIZE = 16 };
 	long pseudoRandomDir[PRSIZE];
 	int nextPR;
 	void initPseudoRandom();
