@@ -68,7 +68,7 @@ ExecDlg::ExecDlg(QWidget *parent, ExecutableStructure *structure)
 	mainlayout->addWidget(captionlabel);
 
 	cpuusagelabel = new QLabel(this);
-	cpuusagelabel->setText(i18n("cpu usage: unknown"));
+	cpuusagelabel->setText(i18n("CPU usage: unknown"));
 
     cpuusagetimer = new QTimer( this );
 	connect( cpuusagetimer, SIGNAL(timeout()),
@@ -115,11 +115,11 @@ ExecDlg::ExecDlg(QWidget *parent, ExecutableStructure *structure)
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"));
+	bbox->addButton(i18n("Help"), this, SLOT( help() ));
 
 	bbox->addStretch(1);
 
-	QButton *savebutton = bbox->addButton(i18n("&Save..."));
+	QButton *savebutton = bbox->addButton(i18n("&Save As..."));
 	connect( savebutton, SIGNAL( clicked() ), SLOT(saveSession() ) );
 
 	QButton *okbutton = bbox->addButton(i18n("&Quit"));
@@ -156,17 +156,17 @@ void ExecDlg::updateCpuUsage()
 	{
 		cpuusagetimer->stop();
 		accept();
-		PortableKDE::KMsgSorry(this,i18n("Your synthesis has been interrupted due to excessive cpu load."));
+		PortableKDE::KMsgSorry(this,i18n("Your synthesis has been interrupted due to excessive CPU load."));
 		/*
 		KMsgBox::message(this,i18n("Error"),
-		  i18n("Your synthesis has been interrupted due to too high cpu load."),
+		  i18n("Your synthesis has been interrupted due to excessive CPU load."),
 		  KMsgBox::STOP);
 		*/
 		// warning: this is invalid after accept();
 		return;
 	}
 	sprintf(cpuusage,"%s%3.2f%%",
-		(const char *)i18n("cpu usage: "),s.cpu_usage*100);
+		(const char *)i18n("CPU usage: "),s.cpu_usage*100);
 
 	cpuusagelabel->setText(cpuusage);
 
@@ -193,4 +193,9 @@ void ExecDlg::saveSession()
 		structure->saveSession(QFile::encodeName(filename));
 	}
 }
+
+void ExecDlg::help()
+{
+	KApplication::kApplication()->invokeHelp("", "karts");
+}
 #include "execdlg.moc"
