@@ -35,7 +35,6 @@
 #include "portposdlg.h"
 #include "interfacedlg.h"
 #include "execdlg.h"
-#include "namedlg.h"
 #include "retrievedlg.h"
 
 #include "config.h"
@@ -47,6 +46,7 @@
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
+#include <klineeditdlg.h>
 #include <kstdaccel.h>
 #include <kfiledialog.h>
 #include <ksavefile.h>
@@ -62,7 +62,6 @@
 #include <list>
 #include <iostream>
 
-#include <string.h>
 #include <unistd.h>
 #include <string.h> // strerror always here?
 //#include <errno.h>
@@ -228,8 +227,9 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
 	menumaker->addCategory(i18n("&Synthesis/&Tests"), "Arts::Synth_DEBUG$");
 	menumaker->addCategory(i18n("&Synthesis/&Tests"), "Arts::Synth_DATA$");
 	menumaker->addCategory(i18n("&Synthesis/&Tests"), "Arts::Synth_MIDI_DEBUG$");
-	menumaker->addCategory(i18n("&Synthesis/&Oscillation & Modulation"), "Arts::Synth_FREQUENCY$");
-	menumaker->addCategory(i18n("&Synthesis/&Oscillation & Modulation"), "Arts::Synth_FM_SOURCE$");
+	menumaker->addCategory(i18n("&Synthesis/&Oscillation && Modulation"), "Arts::Synth_FREQUENCY$");
+	menumaker->addCategory(i18n("&Synthesis/&Oscillation && Modulation"), "Arts::Synth_FM_SOURCE$");
+	menumaker->addCategory(i18n("&Synthesis/&Oscillation && Modulation"), "Arts::Synth_OSC$");
 	menumaker->addCategory(i18n("&Synthesis/&WaveForms"), "Arts::Synth_WAVE_");
 	menumaker->addCategory(i18n("&Synthesis/&WaveForms"), "Arts::Synth_NOISE$");
 	menumaker->addCategory(i18n("&Synthesis/&Internal"), "Arts::Synth_PARAM_");
@@ -299,9 +299,9 @@ void ArtsBuilderWindow::setupActions()
 					  actionCollection(), "file_open_example");
 	KStdAction::save(this, SLOT(save()), actionCollection());
 	KStdAction::saveAs(this, SLOT(saveAs()), actionCollection());
-	(void)new KAction(i18n("&Retrieve from server..."), Qt::CTRL + Qt::Key_R, this, SLOT(retrieve()),
+	(void)new KAction(i18n("&Retrieve From Server..."), Qt::CTRL + Qt::Key_R, this, SLOT(retrieve()),
 					  actionCollection(), "file_retrieve_from_server");
-	(void)new KAction(i18n("&Execute Structure..."), "artsbuilderexecute", Qt::CTRL + Qt::Key_E, this, SLOT(execute()),
+	(void)new KAction(i18n("&Execute Structure"), "artsbuilderexecute", Qt::CTRL + Qt::Key_E, this, SLOT(execute()),
 					  actionCollection(), "file_execute_structure");
 	(void)new KAction(i18n("&Rename Structure..."), Qt::CTRL + Qt::Key_R, this, SLOT(rename()),
 					  actionCollection(), "file_rename_structure");
@@ -328,17 +328,17 @@ void ArtsBuilderWindow::setupActions()
 					  actionCollection(), "view_50");
 
 	// Ports menu
-	(void)new KAction(i18n("Create IN audio signal"), 0, this, SLOT(createInAudioSignal()),
+	(void)new KAction(i18n("Create IN Audio Signal"), 0, this, SLOT(createInAudioSignal()),
 					  actionCollection(), "ports_create_in_audio_signal");
-	(void)new KAction(i18n("Create OUT audio signal"), 0, this, SLOT(createOutAudioSignal()),
+	(void)new KAction(i18n("Create OUT Audio Signal"), 0, this, SLOT(createOutAudioSignal()),
 					  actionCollection(), "ports_create_out_audio_signal");
-	(void)new KAction(i18n("Create IN string property"), 0, this, SLOT(createInStringProperty()),
+	(void)new KAction(i18n("Create IN String Property"), 0, this, SLOT(createInStringProperty()),
 					  actionCollection(), "ports_create_in_string_property");
-	(void)new KAction(i18n("Create IN audio property"), 0, this, SLOT(createInAudioProperty()),
+	(void)new KAction(i18n("Create IN Audio Property"), 0, this, SLOT(createInAudioProperty()),
 					  actionCollection(), "ports_create_in_audio_property");
-	(void)new KAction(i18n("Implement interface ..."), 0, this, SLOT(addInterface()),
+	(void)new KAction(i18n("Implement Interface..."), 0, this, SLOT(addInterface()),
 					  actionCollection(), "ports_implement_interface");
-	(void)new KAction(i18n("Change positions/names"), 0, this, SLOT(changePortPositions()),
+	(void)new KAction(i18n("Change Positions/Names..."), 0, this, SLOT(changePortPositions()),
 					  actionCollection(), "ports_change_positions");
 }
 
@@ -563,7 +563,7 @@ void ArtsBuilderWindow::saveAs()
 	KFileDialog *dlg = new KFileDialog(0, "*.arts", this, 0, true /*,false TODO: acceptURLs */);
 
 	dlg->setSelection(defaultname.c_str());
-	dlg->setCaption(i18n("Save as"));
+	dlg->setCaption(i18n("Save As"));
 
 	QString filename;
 	if(dlg->exec() == QDialog::Accepted)
@@ -626,11 +626,12 @@ void ArtsBuilderWindow::checkName()
 
 void ArtsBuilderWindow::rename()
 {
-	NameDlg nd(0, structure->name().c_str(), i18n("Rename Structure"));
-	if(nd.exec())
+	KLineEditDlg dlg(i18n("Enter structure name:"), structure->name().c_str(), this);
+	dlg.setCaption(i18n("Rename Structure"));
+	if (dlg.exec())
 	{
 		arts_debug("rename OK...");
-		structure->rename(nd.name().local8Bit());
+		structure->rename(dlg.text().local8Bit());
 	}
 	
 	setModified(true);
