@@ -25,7 +25,7 @@
 #include "mwidget.h"
 
 #include <kdockwidget.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kfiledialog.h>
 #include <ksimpleconfig.h>
 
