@@ -22,7 +22,6 @@
 #ifndef __MODULE_H_
 #define __MODULE_H_
 
-
 #include <list>
 
 #include <qpixmap.h>
@@ -36,15 +35,16 @@
 class ModulePort
 {
 	//ModulePort *connection;
+	
 public:
 	Arts::PortDesc PortDesc;
 	long pdID;
 
-	enum ConnType {none,source,dest,value,conf};
-	enum Direction {in,out};
+	enum ConnType {none, source, dest, value, conf};
+	enum Direction {in, out};
 
-	bool 		selected;
-	StructureComponent	   *owner;
+	bool 				 selected;
+	StructureComponent	*owner;
 
 	QString		description;
 	QRect		clickrect;
@@ -55,7 +55,7 @@ public:
 
 	long		route_owner;
 
-	ModulePort(StructureComponent *owner, const std::string& description, 
+	ModulePort( StructureComponent *owner, const std::string& description,
 				int drawsegment, Direction direction, Arts::PortDesc PortDesc);
 
 	bool down();
@@ -68,18 +68,19 @@ protected:
 	Arts::StructureDesc StructureDesc;
 	Arts::ModuleDesc    ModuleDesc;
 
-	int _x,_y,_width,_height;
-	bool _selected, _visible;
 	QPixmap *_pixmap;
 	QString _name;
 
+	int _width, _height;
+	bool moveInternal(int x, int y);
+
 	void initModule();
 
 public:
-	Module(Arts::ModuleDesc moduledesc, Arts::StructureDesc structuredesc,
-											StructureCanvas *canvas);
-	Module(const Arts::ModuleInfo& minfo, Arts::StructureDesc structuredesc,
-											StructureCanvas *canvas);
+	Module( Arts::ModuleDesc moduledesc, Arts::StructureDesc structuredesc,
+			StructureCanvas *canvas);
+	Module( const Arts::ModuleInfo& minfo, Arts::StructureDesc structuredesc,
+			StructureCanvas *canvas);
 	virtual ~Module();
 
 	ModulePort *findPort(int xoffset, int direction);
@@ -87,33 +88,21 @@ public:
 	bool isInterface;
 
 	long mdID;
-	std::list<ModulePort *> inports,outports;
+	std::list<ModulePort *> inports, outports;
 
 // StructureComponent interface
 
+	int width() const;
+	int height() const;
 	ComponentType type();
 
 	ModulePort *portAt(int segment, int x, int y);
 	void dumpPorts(std::list<ModulePort *>& ports);
 
-	bool visible();
-	void show();
-	void hide();
-
 	bool drawNeedsBackground(int segment);
 	void drawSegment(QPainter *dest, int cellsize, int segment);
 	QPixmap *pixmap();
-	const char *name();
-
-	bool selected();
-	void setSelected(bool newselection);
-
-	// in cells
-	bool move(int x, int y);
-	int width();
-	int height();
-	int x();
-	int y();
-};
+	QString name();
+ };
 
 #endif
