@@ -20,13 +20,13 @@
     */
 
 #include "portposdlg.h"
-#include "namedlg.h"
 #include "structureport.h"
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qlistbox.h>
 #include <kbuttonbox.h>
 #include <klocale.h>
+#include <klineeditdlg.h>
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
 #include <kapplication.h>
@@ -110,22 +110,22 @@ PortPosDlg::PortPosDlg(QWidget *parent, Structure *structure) :QDialog(parent,"P
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"));
+	bbox->addButton(i18n("&Help"), this, SLOT( help() ));
 	bbox->addStretch(1);
 
 	KIconLoader iconloader;
-	QButton *raise = bbox->addButton(i18n("Raise"));
+	QButton *raise = bbox->addButton(i18n("&Raise"));
 	raise->setPixmap(iconloader.loadIcon("up", KIcon::Small));
 	connect( raise, SIGNAL( clicked() ), SLOT( raise() ));
 
-	QButton *lower = bbox->addButton(i18n("Lower"));
+	QButton *lower = bbox->addButton(i18n("&Lower"));
 	lower->setPixmap(iconloader.loadIcon("down", KIcon::Small));
 	connect( lower, SIGNAL( clicked() ), SLOT( lower() ));
 
-	QButton *rename = bbox->addButton(i18n("Rename"));
+	QButton *rename = bbox->addButton(i18n("R&ename..."));
 	connect( rename, SIGNAL( clicked() ), SLOT( rename() ));
 
-	QButton *okbutton = bbox->addButton(i18n("Okay"));
+	QButton *okbutton = bbox->addButton(i18n("&OK"));
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
 
 /*
@@ -186,15 +186,13 @@ void PortPosDlg::rename()
 	StructurePort *port = listports[i];
 	assert(port);
 
-	NameDlg *nd = new NameDlg(0,port->name(),i18n("Rename Port"));
-	assert(nd);
-
-	if(nd->exec())
+	KLineEditDlg dlg(i18n("Enter port name:"), port->name(), this);
+	dlg.setCaption(i18n("Rename Port"));
+	if (dlg.exec())
 	{
 		arts_debug("rename OK...");
-		port->rename(nd->name().local8Bit());
+		port->rename(dlg.text().local8Bit());
 	}
-	delete nd;
 	update();
 
 	unsigned long l;
@@ -249,4 +247,10 @@ void PortPosDlg::update()
 	}
 	listbox->repaint();
 }
+
+void PortPosDlg::help()
+{
+	KApplication::kApplication()->invokeHelp("", "karts");
+}
+
 #include "portposdlg.moc"
