@@ -35,11 +35,9 @@
 #include <arts/debug.h>
 #include <qpushbutton.h>
 
-#ifndef KDE_USE_FINAL
 static void min_size(QWidget *w) {
   w->setMinimumSize(w->sizeHint());
 } 
-#endif
 
 RetrieveDlg::RetrieveDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 {
@@ -105,13 +103,13 @@ RetrieveDlg::RetrieveDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"));
+	bbox->addButton(i18n("&Help"), this, SLOT( help() ));
 	bbox->addStretch(1);
 
-	QButton *cancelbutton = bbox->addButton(i18n("Cancel"));
+	QButton *cancelbutton = bbox->addButton(i18n("&Cancel"));
 	connect( cancelbutton, SIGNAL( clicked() ), SLOT(reject() ) );
 
-	QButton *okbutton = bbox->addButton(i18n("Okay"));
+	QButton *okbutton = bbox->addButton(i18n("&OK"));
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
 
 	bbox->layout();
@@ -130,4 +128,9 @@ QString RetrieveDlg::result()
 	}
 	return QString::null;
 }
+
+void RetrieveDlg::help()
+{
+	KApplication::kApplication()->invokeHelp("", "karts");
+}
 #include "retrievedlg.moc"
