@@ -27,7 +27,7 @@
 #include <qdialog.h>
 #include <qtimer.h>
 #include <qlabel.h>
-#include <qscrbar.h>
+#include <qscrollbar.h>
 #include <qlined.h>
 #include <qlayout.h>
 #include <qlistbox.h>
@@ -39,5 +39,7 @@ class RetrieveDlg :public QDialog {
 public:
 	RetrieveDlg(QWidget *parent);
 	QString result();
+public slots:
+	void help();
 };
 #endif
