@@ -23,7 +23,7 @@
 #include "soundserver.h"
 #include "kartsserver.h"
 #include <stdio.h>
-#include <iostream.h>
+#include <iostream>
 #include <fstream>
 #include <arts/debug.h>
 
