@@ -29,6 +29,8 @@ KHBox_impl::KHBox_impl(QHBox *qhbox /* = 0 */)
 	: KWidget_impl(qhbox?qhbox:new QHBox((QWidget *)0))
 {
 	this->qhbox = (QHBox *)qwidget;
+	this->qhbox->setMargin(5);
+	this->qhbox->setSpacing(5);
 }
 
 REGISTER_IMPLEMENTATION(KHBox_impl);
