@@ -27,6 +27,7 @@
 #include <math.h>
 #include <iostream.h>
 #include <qpen.h>
+#include <qstring.h>
 
 #define PI 3.1415926
 static const int motifBorder = 2;
@@ -84,11 +85,11 @@ void KPoti::init(int value)
   label=TRUE;
   tickInt = 0;
   fontHeight=fontMetrics().height();
-  
+
   space = QMIN( height(), width() );
-  center.setX(space/2); center.setY(space/2); 
+  center.setX(space/2); center.setY(space/2);
   setBackgroundMode( PaletteMid );
-  
+
   setFocusPolicy( TabFocus );
   initTicks();
 }
@@ -99,23 +100,23 @@ void KPoti::init(int value)
 */
 
 void KPoti::initTicks()
-{ 
+{
 
   space = QMIN( height(), width() );
-  center.setX(width()/2); 
+  center.setX(width()/2);
   if (label==TRUE) {
     space -= fontSize -2;
   }
-  if ( ticks == TRUE ) 
+  if ( ticks == TRUE )
   {
     double spaced = space;
 	spaced /= 1.0+tickLength/2;
 
     space=(int)spaced;
   }
-  
+
   buttonRadius = (space-1)/2 ; center.setY(height()-buttonRadius-1);
- 
+
 }
 
 
@@ -201,7 +202,7 @@ void KPoti::rangeChange()
 {
     float newPos = positionFromValue( value() );
     if ( newPos != potiPos ) {
-	reallyMovePoti( newPos ); 
+	reallyMovePoti( newPos );
     }
 }
 
@@ -238,7 +239,7 @@ void KPoti::resizeEvent( QResizeEvent * )
 
 void KPoti::setPalette( const QPalette &p )
 {
-  
+
     setBackgroundMode( PaletteMid );
     QWidget::setPalette( p );
 }
@@ -265,7 +266,7 @@ void KPoti::paintPoti( QPainter *p)
   QColorGroup g = colorGroup();
   p->setBrush( color );
   QCOORD x=center.x(), y=center.y();
-  
+
 
   //qDrawShadePanel( p, r, g, FALSE, 2, &fill );
   p->drawEllipse(x-buttonRadius+5,y-buttonRadius+5,
@@ -287,7 +288,7 @@ void KPoti::paintPoti( QPainter *p)
 void KPoti::reallyMovePoti( float newPos )
 {
   QPainter p;
-  p.begin( this );  
+  p.begin( this );
   p.setPen(NoPen);
   potiPos = newPos;
   paintPoti(&p);
@@ -303,13 +304,13 @@ void KPoti::reallyMovePoti( float newPos )
 
 void KPoti::paintEvent( QPaintEvent *e )
 {
-    
+
     QPainter p;
     QPen pen;
     p.begin( this );
     QRect paintRect = e->rect();
     p.setClipRect( paintRect );
-    
+
     QColorGroup g = colorGroup();
 	if(backgroundMode() == FixedPixmap)
 	{
@@ -319,13 +320,13 @@ void KPoti::paintEvent( QPaintEvent *e )
 	{
     	p.fillRect( 0, 0, width(), height(), g.background() );
 	}
-    
+
     const QColor c0 = black;
     const QColor c4 = g.light();
 
     QFont font;
     font=p.font(); font.setPointSize(8); p.setFont(font);
-    p.drawText(0,fontSize,name());
+    p.drawText(0,fontSize,QString::fromUtf8(name()));
 
     int interval = tickInt;
     if ( interval <= 0 ) {
@@ -333,8 +334,8 @@ void KPoti::paintEvent( QPaintEvent *e )
     }
     if (ticks)
 	drawTicks( &p, buttonRadius+2, (int)(buttonRadius*(1+tickLength)), interval );
-	
- 
+
+
     p.setBrush(darkGray);
     p.drawEllipse(center.x()-buttonRadius,center.y()-buttonRadius,
 	       2*(buttonRadius),2*(buttonRadius));
@@ -346,7 +347,7 @@ void KPoti::paintEvent( QPaintEvent *e )
     p.setPen(pen);
     p.drawArc(center.x()-buttonRadius+3,center.y()-buttonRadius+3,
 	      2*(buttonRadius-3),2*(buttonRadius-3), 45*16,-180*16);
-  
+
     p.setPen(c4);
     p.drawArc(center.x()-buttonRadius,center.y()-buttonRadius,
 	      2*buttonRadius,2*buttonRadius, 45*16,-180*16);
@@ -355,7 +356,7 @@ void KPoti::paintEvent( QPaintEvent *e )
     p.setPen(pen);
     p.drawArc(center.x()-buttonRadius+3,center.y()-buttonRadius+3,
 	      2*(buttonRadius-3),2*(buttonRadius-3), 45*16,180*16);
-  
+
     if ( hasFocus() ) {
       p.setPen( black ); p.setBrush(NoBrush);
       p.drawRect(  0,0, width(), height() );
@@ -385,10 +386,10 @@ void KPoti::mousePressEvent( QMouseEvent *e )
   }
   if ( e->button() != LeftButton )
     return;
- 
-  
+
+
   int dx=e->pos().x()-center.x(), dy=e->pos().y()-center.y();
-  
+
   if ( dx*dx+dy*dy < buttonRadius*buttonRadius ) {
     state = Dragging;
     clickOffset =  potiVal + (e->pos().y() ) ;
@@ -399,14 +400,14 @@ void KPoti::mousePressEvent( QMouseEvent *e )
     if ( !timer )
       timer = new QTimer( this );
     connect( timer, SIGNAL(timeout()), SLOT(repeatTimeout()) );
-    timer->start( thresholdTime, TRUE ); 
+    timer->start( thresholdTime, TRUE );
   } else  {
     state = TimingUp;
     addPage();
     if ( !timer )
       timer = new QTimer( this );
     connect( timer, SIGNAL(timeout()), SLOT(repeatTimeout()) );
-    timer->start( thresholdTime, TRUE ); 
+    timer->start( thresholdTime, TRUE );
   }
 }
 
@@ -420,14 +421,14 @@ void KPoti::mouseMoveEvent( QMouseEvent *e )
       double pos = atan2( double(e->pos().x()-center.x()),
                           double(- e->pos().y()+center.y()) );
       movePoti( pos );
-      return;	
+      return;
     }
     if ( !(e->state() & LeftButton) )
 	return;					// left mouse button is up
     if ( state != Dragging )
 	return;
-    
-    
+
+
     movePoti( positionFromValue(- e->pos().y() + clickOffset ));
 }
 
@@ -464,7 +465,7 @@ void KPoti::enterEvent( QEvent * )
 
 
 /*!
-  Moves the left (or top) edge of the slider to position 
+  Moves the left (or top) edge of the slider to position
   \a pos. Performs snapping.
 */
 
@@ -521,7 +522,7 @@ void KPoti::resetState()
 
 void KPoti::keyPressEvent( QKeyEvent *e )
 {
- 
+
     switch ( e->key() ) {
     case Key_Left:
       subtractLine();
@@ -600,15 +601,15 @@ void KPoti::repeatTimeout()
 	connect( timer, SIGNAL(timeout()), SLOT(subtractStep()) );
     else if ( state == TimingUp )
 	connect( timer, SIGNAL(timeout()), SLOT(addStep()) );
-    timer->start( repeatTime, FALSE );   
+    timer->start( repeatTime, FALSE );
 }
 
 
 
 
-/*!  
+/*!
   Using \a p, draws tickmarks at a distance of \a d from the edge
-  of the widget, using \a w pixels and \a i intervals.  
+  of the widget, using \a w pixels and \a i intervals.
   */
 
 void KPoti::drawTicks( QPainter *p, int d, int w, int i ) const
@@ -631,7 +632,7 @@ void KPoti::wheelEvent(QWheelEvent *e)
 
 
 /*!
-  Sets the way tickmarks are displayed by the slider. \a s can take 
+  Sets the way tickmarks are displayed by the slider. \a s can take
   the following values:
   <ul>
   <li> \c NoMarks
@@ -655,9 +656,9 @@ void KPoti::setTickmarks( bool s )
 
 
 /*!
-  Sets the interval between tickmarks to \a i. This is a value interval, 
+  Sets the interval between tickmarks to \a i. This is a value interval,
   not a pixel interval. If \a i is 0, the slider
-  will choose between lineStep() and pageStep(). The initial value of 
+  will choose between lineStep() and pageStep(). The initial value of
   tickInterval() is 0.
   \sa tickInterval(), QRangeControl::lineStep(), QRangeControl::pageStep()
 */
