@@ -29,7 +29,7 @@ class KVBox_impl : virtual public Arts::VBox_skel,
 				   virtual public Arts::KWidget_impl
 {
 protected:
-	QVBox *qhbox;
+	QVBox *qvbox;
 public:
 	KVBox_impl(QVBox *qhbox = 0);
 };
