@@ -5,6 +5,8 @@
 #include "connect.h"
 #include "flowsystem.h"
 #include "debug.h"
+#include "dynamicrequest.h"
+#include "audiosubsys.h"
 #include <fstream>
 #include <math.h>
 
@@ -22,9 +24,38 @@ protected:
 	void loadLine(const string& line);
 
 public:
+	struct InstrumentParam;
+
 	void loadFromList(const string& filename, const vector<string>& list);
 	StructureDesc getInstrument(mcopbyte channel, mcopbyte note,
-										mcopbyte velocity, mcopbyte program);
+										mcopbyte velocity, mcopbyte program,
+										vector<InstrumentParam>*& params);
+};
+
+struct InstrumentMap::InstrumentParam
+{
+	string param;
+	Any value;
+
+	InstrumentParam()
+	{
+	}
+
+	InstrumentParam(const InstrumentParam& src)
+		: param(src.param), value(src.value)
+	{
+	}
+
+	InstrumentParam(const string& param, const string& strValue)
+		: param(param)
+	{
+		/* put the string into the any */
+		value.type = "string";
+
+		Buffer b;
+		b.writeString(strValue);
+		b.read(value.value, b.size());
+	}
 };
 
 struct InstrumentMap::InstrumentData 
@@ -45,6 +76,7 @@ struct InstrumentMap::InstrumentData
 		}
 	};
 	Range channel, pitch, program, velocity;
+	vector<InstrumentParam> params;
 	StructureDesc instrument;
 };
 
@@ -158,7 +190,7 @@ void InstrumentMap::loadLine(const string& line)
 
 						/* if it's no absolute path, its relative to the map */
 						if(!filename.empty() && filename[0] != '/')
-							filename = directory + s[2];
+							filename = directory + "/" + s[2];
 
 						ifstream infile(filename.c_str());
 						string line;
@@ -178,6 +210,11 @@ void InstrumentMap::loadLine(const string& line)
 									"can't load structure %s",s[2].c_str());
 						}
 					}
+					else
+					{
+						/* TODO: handle different datatypes */
+						id.params.push_back(InstrumentParam(s[0], s[2]));
+					}
 				}
 				else
 				{
@@ -219,7 +256,8 @@ void InstrumentMap::loadFromList(const string& filename,
 }
 
 StructureDesc InstrumentMap::getInstrument(mcopbyte channel, mcopbyte note,
-											mcopbyte velocity, mcopbyte program)
+											mcopbyte velocity, mcopbyte program,
+											vector<InstrumentParam>*& params)
 {
 	list<InstrumentData>::iterator i;
 	for(i = instruments.begin(); i != instruments.end(); i++)
@@ -229,6 +267,7 @@ StructureDesc InstrumentMap::getInstrument(mcopbyte channel, mcopbyte note,
 		if(id.channel.match(channel) && id.pitch.match(note) &&
 		   id.velocity.match(velocity) && id.program.match(program))
 		{
+			params = &id.params;
 			return id.instrument;
 		}
 	}
@@ -259,8 +298,6 @@ struct TSNote {
 	}
 };
 
-static vector<TSNote> noteQueue;
-
 class AutoMidiRelease : public TimeNotify {
 public:
 	vector<MidiReleaseHelper> impls;
@@ -274,26 +311,6 @@ public:
 	}
 	void notifyTime()
 	{
-		timeval tv;
-		gettimeofday(&tv,0);
-		vector<TSNote>::iterator n = noteQueue.begin();
-		while(n != noteQueue.end())
-		{
-			TSNote& note = *n;
-			TimeStamp& time = note.event.time;
-
-			if( tv.tv_sec > time.sec 
-			|| ((tv.tv_sec == time.sec) && (tv.tv_usec > time.usec)))
-			{
-				note.port.processCommand(note.event.command);
-
-				noteQueue.erase(n);
-				n = noteQueue.begin();
-			}
-			else n++;
-		}
-
-
 		vector<MidiReleaseHelper>::iterator i = impls.begin();
 		while(i != impls.end())
 		{
@@ -387,8 +404,10 @@ protected:
 	AudioManagerClient amClient;
 	ObjectCache cache;
 	MidiClient client;
+	MidiTimer timer;
 
 	string _filename;
+	string _busname;
 	string _title;
 public:
 	Synth_MIDI_TEST self() { return Synth_MIDI_TEST::_from_base(_copy()); }
@@ -401,6 +420,11 @@ public:
 	{
 		return _filename;
 	}
+	void busname(const string& newname);
+	string busname()
+	{
+		return _busname;
+	}
 	string title()
 	{
 		return _title;
@@ -416,13 +440,34 @@ public:
 
 	TimeStamp time()
 	{
-		timeval tv;
-		gettimeofday(&tv, 0);
-		return TimeStamp(tv.tv_sec, tv.tv_usec);
+		return timer.time();
+	}
+	TimeStamp playTime()
+	{
+		/*
+		 * what the user currently hears is exactly latencySec before our
+		 * port timeStamp (as this is the size of the audio buffer)
+		 */
+		double latencySec = AudioSubSystem::the()->outputDelay();
+		TimeStamp t = time();
+
+		int sec = int(latencySec);
+		t.sec -= sec;
+		latencySec -= double(sec);
+		t.usec -= int(latencySec * 1000000.0);
+
+		if (t.usec < 0)
+		{
+			t.usec += 1000000;
+			t.sec -= 1;
+		}
+
+		arts_assert(t.usec >= 0 && t.usec < 1000000);
+		return t;
 	}
 	void processEvent(const MidiEvent& event)
 	{
-		noteQueue.push_back(TSNote(self(),event));
+		timer.queueEvent(self(),event);
 	}
 	void processCommand(const MidiCommand& command)
 	{
@@ -439,12 +484,9 @@ public:
 			case mcsProgram: channelData[channel].program = command.data1;
 				return;
 			case mcsParameter:
-					if(command.data1 == 0x7b && command.data2 == 0)
-					{
-						// all notes off event
+					if(command.data1 == mcpAllNotesOff && command.data2 == 0)
 						for(mcopbyte note=0; note<128; note++)
 							noteOff(channel,note);
-					}
 				return;
 		}
 	}
@@ -452,6 +494,12 @@ public:
 REGISTER_IMPLEMENTATION(Synth_MIDI_TEST_impl);
 
 
+void Synth_MIDI_TEST_impl::busname(const string& newname)
+{
+	// TODO:
+	_busname = newname;
+}
+
 void Synth_MIDI_TEST_impl::filename(const string& newname)
 {
 	ifstream infile(newname.c_str());
@@ -499,6 +547,7 @@ Synth_MIDI_TEST_impl::Synth_MIDI_TEST_impl()
 {
 	useMap = false;
 	client = MidiClient::null();
+	timer = SubClass("Arts::AudioMidiTimer");
 	channelData = new ChannelData[16];
 }
 
@@ -540,10 +589,11 @@ void Synth_MIDI_TEST_impl::noteOn(mcopbyte channel, mcopbyte note,
 		arts_info("Synth_MIDI_TEST: duplicate noteOn (mixed channels?)");
 	}
 
+	vector<InstrumentMap::InstrumentParam> *params = 0;
 	if(useMap)
 	{
 		mcopbyte program = channelData[channel].program;
-		StructureDesc sd = map.getInstrument(channel,note,velocity,program);
+		StructureDesc sd = map.getInstrument(channel,note,velocity,program,params);
 		if(sd.isNull()) return;
 		instrument = sd;
 	}
@@ -554,7 +604,19 @@ void Synth_MIDI_TEST_impl::noteOn(mcopbyte channel, mcopbyte note,
 		arts_debug("creating new structure");
 		structureObject = builder.createObject(instrument);
 
-		Synth_AMAN_PLAY play(amClient);
+		SynthModule play;
+		// TODO: allow changing busname!
+		if(_busname != "")
+		{
+			Synth_BUS_UPLINK b;
+			b.busname(_busname);
+			play = b;
+		}
+		else
+		{
+			Synth_AMAN_PLAY a(amClient);
+			play = a;
+		}
 		structureObject._addChild(play,"play");
 		connect(structureObject,"left",play,"left");
 		connect(structureObject,"right",play,"right");
@@ -567,6 +629,16 @@ void Synth_MIDI_TEST_impl::noteOn(mcopbyte channel, mcopbyte note,
 	SynthModule structure = DynamicCast(structureObject);
 	assert(!structure.isNull());
 
+	if(params)
+	{
+		vector<InstrumentMap::InstrumentParam>::iterator pi;
+		for(pi = params->begin(); pi != params->end(); pi++)
+		{
+			DynamicRequest req(structure);
+
+			req.method("_set_"+pi->param).param(pi->value).invoke();
+		}
+	}
 	setValue(structure,"frequency",getFrequency(note,channel));
 	setValue(structure,"velocity",(float)velocity/127.0);
 	setValue(structure,"pressed",1.0);
