@@ -1,8 +1,8 @@
 #include "artsbuilder.h"
 #include "weakreference.h"
-#include "sequenceutils.h"
 #include "moduleinfo.h"
 #include "compatibility.h"
+#include "sequenceutils.h"
 #include <stdio.h>
 #include <iostream>
 
@@ -103,6 +103,7 @@ protected:
 	bool _valid;
 	vector<ModuleDesc> _modules;
 	vector<StructurePortDesc> _ports;	/* only structure ports which are part of the interface */
+	vector<string> _inheritedInterfaces;
 	long nextID;
 	ModuleInfo _externalInterface;
 
@@ -115,6 +116,7 @@ public:
 	void loadFromList(const vector<string>& list);
 	vector<ModuleDesc> *modules();
 	vector<StructurePortDesc> *ports();
+	vector<string> *inheritedInterfaces();
 
 	void clear();
 	long obtainID();
@@ -133,6 +135,9 @@ public:
 
 	ModuleInfo externalInterface();
 
+	void addInheritedInterface(const string& iface);
+	void removeInheritedInterface(const string& iface);
+
 	StructureDesc_impl();
 	~StructureDesc_impl();
 };
@@ -144,6 +149,7 @@ class StructurePortDesc_impl :
 protected:
 	StructureDesc_wref _parentStructure;
 	long _x, _y, _position;
+	string _inheritedInterface;
 
 	inline StructurePortDesc self() {
 		return StructurePortDesc::_from_base(_copy());
@@ -159,6 +165,8 @@ public:
 	void lowerPosition();
 	void raisePosition();
 	void rename(const string& newname);
+	string inheritedInterface();
+	void inheritedInterface(const string& iface);
 
 	void internalSetPosition(long position);
 	StructureDesc parentStructure();
@@ -175,7 +183,6 @@ REGISTER_IMPLEMENTATION(StructurePortDesc_impl);
 
 /*
 #include "structures.h"
-#include "sequenceutils.h"
 */
 #include "debug.h"
 #include <vector>
@@ -663,6 +670,28 @@ vector<ModuleDesc> *StructureDesc_impl::modules()
 	return(retval);
 }
 
+void StructureDesc_impl::addInheritedInterface(const string& iface)
+{
+	_inheritedInterfaces.push_back(iface);
+}
+
+void StructureDesc_impl::removeInheritedInterface(const string& iface)
+{
+	vector<string> newII;
+	vector<string>::iterator ii;
+
+	for(ii = _inheritedInterfaces.begin(); ii != _inheritedInterfaces.end(); ii++)
+		if(*ii != iface)
+			newII.push_back(*ii);
+
+	_inheritedInterfaces = newII;
+}
+
+vector<string> *StructureDesc_impl::inheritedInterfaces()
+{
+	return new vector<string>(_inheritedInterfaces);
+}
+
 StructureDesc_impl::StructureDesc_impl()
 {
 	arts_debug("PORT: created structuredesc_impl");
@@ -692,6 +721,7 @@ void StructureDesc_impl::clear()
 {
 	_modules.clear();
 	_ports.clear();
+	_inheritedInterfaces.clear();
 	_valid = true;
 }
 
@@ -758,6 +788,7 @@ vector<string> *StructureDesc_impl::saveToList()
 	vector<string> *list = new vector<string>;
 	vector<ModuleDesc>::iterator mi;
 	vector<StructurePortDesc>::iterator pi;
+	vector<string>::iterator ii;
 
 	sqprintf(list,"name=%s",_externalInterface.name.c_str());
 	for(mi=_modules.begin();mi != _modules.end();mi++)
@@ -778,6 +809,9 @@ vector<string> *StructureDesc_impl::saveToList()
 		addSubStringSeq(list,portlist);
 		delete portlist;
 	}
+	for(ii=_inheritedInterfaces.begin(); ii != _inheritedInterfaces.end(); ii++)
+		sqprintf(list,"interface=%s",ii->c_str());
+
 	return list;
 }
 
@@ -918,6 +952,10 @@ void StructureDesc_impl::loadFromList(const vector<string>& list)
 			{
 				_externalInterface.name = param;
 			}
+			else if(cmd == "interface")
+			{
+				_inheritedInterfaces.push_back(param);
+			}
 			else if(cmd == "structureport")
 			{
 				// just to have valid values to pass to the new (to be loaded)
@@ -926,6 +964,7 @@ void StructureDesc_impl::loadFromList(const vector<string>& list)
 				type.direction = Arts::input;
 				type.dataType = "float";
 				type.connType = Arts::conn_stream;
+				type.isMultiPort = false;
 
 				StructurePortDesc spd =
 					createStructurePortDesc(type,"unknown");
@@ -1146,7 +1185,17 @@ void StructurePortDesc_impl::rename(const string& newname)
 {
 	_name = newname;
 }
- 
+
+void StructurePortDesc_impl::inheritedInterface(const string& iface)
+{
+	_inheritedInterface = iface;
+}
+
+string StructurePortDesc_impl::inheritedInterface()
+{
+	return _inheritedInterface;
+}
+
 // only used by the structure to reorder the ports
 void StructurePortDesc_impl::internalSetPosition(long position)
 {
@@ -1249,6 +1298,7 @@ PortType loadTypeFromList(const vector<string>& list)
 		}
 	}
 	assert(loadstate == 10101); // should see every member exactly once
+	result.isMultiPort = false;
 	return result;
 }
 
@@ -1288,6 +1338,9 @@ void StructurePortDesc_impl::loadFromList(const vector<string>& list)
 			} else if(cmd == "name") {
 				_name = param;
 				artsdebug("Name set to %s\n",_name.c_str());
+			} else if(cmd == "interface") {
+				_inheritedInterface = param;
+				artsdebug("Interface set to %s\n",_inheritedInterface.c_str());
 			}
 		}
 	}
@@ -1348,6 +1401,10 @@ vector<string> *StructurePortDesc_impl::saveToList()
 	sqprintf(list,"x=%ld",_x);
 	sqprintf(list,"y=%ld",_y);
 	sqprintf(list,"position=%ld",_position);
+
+	if(_inheritedInterface != "")
+		sqprintf(list, "interface=%s",_inheritedInterface.c_str());
+
 	sqprintf(list,"type");
 
 	vector<string> *typelist = saveTypeToList(_type);
