@@ -42,7 +42,7 @@ static void min_size(QWidget *w) {
 
 ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 {
-	setCaption(i18n("Choose Destination"));
+	setCaption(i18n("Choose Bus"));
 
 	QVBoxLayout *mainlayout = new QVBoxLayout(this);
 
@@ -102,7 +102,7 @@ ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"));
+	bbox->addButton(i18n("Help"), this, SLOT( help() ));
 	bbox->addStretch(1);
 
 	QButton *cancelbutton = bbox->addButton(i18n("Cancel"));
@@ -127,4 +127,9 @@ QString ChooseBusDlg::result()
 	}
 	return(0);
 }
+
+void ChooseBusDlg::help()
+{
+	KApplication::kApplication()->invokeHelp("", "artsbuilder");
+}
 #include "choosebusdlg.moc"
