@@ -70,7 +70,7 @@ class PeakBar : public LevelMeter {
 	bool clipped;
 
 protected:
-	static const int peakMillis=1500; // how long do the peaks stay at their max?
+	static const int peakMillis; // how long do the peaks stay at their max?
 	
 	class Observation {
 	public:
