@@ -23,6 +23,7 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 
+#include <kapplication.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qfile.h>
@@ -133,7 +134,7 @@ MidiInstDlg::MidiInstDlg(QWidget *parent)
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"));
+	bbox->addButton(i18n("Help"), this, SLOT( help() ));
 	bbox->addStretch(1);
 
 	QButton *okbutton = bbox->addButton(i18n("OK"));
@@ -168,4 +169,10 @@ QCString MidiInstDlg::filename()
 
 	return "";
 }
+
+void MidiInstDlg::help()
+{
+	KApplication::kApplication()->invokeHelp("", "artsbuilder");
+}
+
 #include "midiinstdlg.moc"
