@@ -32,5 +32,7 @@ class MidiInstDlg :public QDialog {
 public:
 	MidiInstDlg(QWidget *parent);
 	QCString filename();
+public slots:
+	void help();
 };
 #endif
