@@ -22,6 +22,7 @@
 #include "midiportdlg.h"
 #include <klocale.h>
 
+#include <kapplication.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include <kseparator.h>
@@ -41,7 +42,7 @@ MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title
 	QFont labelfont(captionlabel->font());
 	labelfont.setPointSize(labelfont.pointSize()*3/2);
 	captionlabel->setFont(labelfont);
-	captionlabel->setText(i18n("OSS Midi Port"));
+	captionlabel->setText(i18n("OSS MIDI Port"));
 	captionlabel->setAlignment(AlignCenter);
 	//min_size(captionlabel);
 	mainlayout->addWidget(captionlabel);
@@ -78,7 +79,7 @@ MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"));
+	bbox->addButton(i18n("Help"), this, SLOT( help() ));
 	bbox->addStretch(1);
 
 	QButton *okbutton = bbox->addButton(i18n("OK"));
@@ -96,4 +97,10 @@ const char *MidiPortDlg::device()
 {
 	return edit->text().ascii();
 }
+
+void MidiPortDlg::help()
+{
+	KApplication::kApplication()->invokeHelp("", "artsbuilder");
+}
+
 #include "midiportdlg.moc"
