@@ -35,5 +35,8 @@ class MidiPortDlg :public QDialog {
 public:
 	MidiPortDlg(QWidget *parent, const char *device, const char *title);
 	const char *device();
+
+public slots:
+	void help();
 };
 #endif
