@@ -22,23 +22,19 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ******************************************************************/
 
 #include <klocale.h>
+#include "kaboodle_factory.h"
+#include "player.h"
 
-#include "kaboodle_part.h"
-#include "kaboodle_factory.moc"
+K_EXPORT_COMPONENT_FACTORY( libkaboodlepart, Kaboodle::KaboodleFactory)
 
-extern "C" void *init_libkaboodlepart()
-{
-	return new KaboodleFactory();
-}
+KInstance *Kaboodle::KaboodleFactory::s_instance = 0;
+KAboutData *Kaboodle::KaboodleFactory::s_aboutData = 0;
 
-KInstance *KaboodleFactory::s_instance = 0;
-KAboutData *KaboodleFactory::s_aboutData = 0;
-
-KaboodleFactory::KaboodleFactory()
+Kaboodle::KaboodleFactory::KaboodleFactory()
 {
 }
 
-KaboodleFactory::~KaboodleFactory()
+Kaboodle::KaboodleFactory::~KaboodleFactory()
 {
 	delete s_aboutData;
 	s_aboutData = 0;
@@ -46,12 +42,19 @@ KaboodleFactory::~KaboodleFactory()
 	s_instance = 0;
 }
 
-KParts::Part *KaboodleFactory::createPartObject(QWidget *widgetParent, const char *widgetName, QObject *parent, const char *name, const char *className, const QStringList &)
+KParts::Part *Kaboodle::KaboodleFactory::createPartObject(QWidget *widgetParent, const char *widgetName, QObject *parent, const char *name, const char *className, const QStringList &)
 {
-	QObject *obj = new KaboodlePart(widgetParent, name, true, true);
+	if(className == QString("KMediaPlayer/Engine"))
+	{
+		return new Player(parent, name);
+	}
+	else
+	{
+		return new Player(widgetParent, widgetName, parent, name);
+	}
 }
 
-KInstance *KaboodleFactory::instance()
+KInstance *Kaboodle::KaboodleFactory::instance()
 {
 	if(!s_instance)
 		s_instance = new KInstance(aboutData());
@@ -59,23 +62,21 @@ KInstance *KaboodleFactory::instance()
 	return s_instance;
 }
 
-const KAboutData *KaboodleFactory::aboutData()
+const KAboutData *Kaboodle::KaboodleFactory::aboutData()
 {
 	if(!s_aboutData)
 	{
-		s_aboutData = new KAboutData("kaboodle", I18N_NOOP("Kaboodle"), "1.4142135623730951", I18N_NOOP("The Lean KDE Media Player"), KAboutData::License_BSD, "(c) 2001 Kaboodle developers");
+		s_aboutData = new KAboutData("kaboodle", I18N_NOOP("Kaboodle"), "1.6",
+		                             I18N_NOOP("The Lean KDE Media Player"),
+		                             KAboutData::License_BSD,
+		                             "(c) 2001 Kaboodle developers", 0,
+		                             "http://www.freekde.org/neil/kaboodle/");
 		s_aboutData->addAuthor("Neil Stevens", I18N_NOOP("Maintainer"), "neil@qualityassistant.com");
 		s_aboutData->addAuthor("Nikolas Zimmermann", I18N_NOOP("Konqueror Embedding"), "wildfox@kde.org");
 		s_aboutData->addAuthor("Charles Samuels", I18N_NOOP("Original Noatun Developer"), "charles@kde.org");
+		s_aboutData->addCredit("Elhay Achiam", I18N_NOOP("Application icon"));
 	}
 	return s_aboutData;
 }
 
-KaboodleBrowserExtension::KaboodleBrowserExtension(KaboodlePart *parent)
-	: KParts::BrowserExtension(parent, "KaboodleBrowserExtension")
-{
-}
-
-KaboodleBrowserExtension::~KaboodleBrowserExtension()
-{
-}
+#include "kaboodle_factory.moc"
