@@ -24,9 +24,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef KABOODLEAPP_H
 #define KABOODLEAPP_H
 
-#include <kapp.h>
-#include "kaboodle_part.h"
+#include <kapplication.h>
 
+namespace Kaboodle
+{
 class KaboodleApp : public KApplication
 {
 Q_OBJECT
@@ -36,5 +37,5 @@ public:
 	virtual ~KaboodleApp();
 
 };
-
+}
 #endif
