@@ -14,10 +14,10 @@
 
 ChannelViewConfigDialog::ChannelViewConfigDialog(QWidget *parent,const char *name) : KDialogBase(parent,name,TRUE,i18n("Configure Channel View"),Ok|Cancel, Ok)
 {
-    QWidget *page = new QWidget( this ); 
+    QWidget *page = new QWidget( this );
     setMainWidget(page);
     QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
-    qbg = new QVButtonGroup(i18n("Choose look mode"),page,"qbg");
+    qbg = new QVButtonGroup(i18n("Choose Look Mode"),page,"qbg");
     
     rb0=new QRadioButton(i18n("3D look"),qbg,"3d");
     rb1=new QRadioButton(i18n("3D - filled"),qbg,"4d");
