@@ -28,6 +28,7 @@
 #include <kapplication.h>
 #include <kfiledialog.h>
 #include <klocale.h>
+#include <klineeditdlg.h>
 #include <kmessagebox.h>
 #include <kurl.h>
 
@@ -35,19 +36,18 @@
 #include "version.h"
 #include "songlist.h"
 #include "slman.h"
-#include "kaskdlg.h"
 
 CollectionDialog::CollectionDialog(SLManager *slm,int selC,QWidget *parent,const char *name) : QDialog(parent,name,TRUE)
 {
 setCaption(i18n("Collections Manager"));
-ok=new QPushButton(i18n("OK"),this);
+ok=new QPushButton(i18n("&OK"),this);
 ok->setGeometry(140,200,100,30);
 connect(ok,SIGNAL(clicked()),SLOT(accept()) );
-cancel=new QPushButton(i18n("Cancel"),this);
+cancel=new QPushButton(i18n("&Cancel"),this);
 cancel->setGeometry(250,200,100,30);
 connect(cancel,SIGNAL(clicked()),SLOT(reject()) );
 
-label=new QLabel(i18n("Available collections :"),this);
+label=new QLabel(i18n("Available collections:"),this);
 label->adjustSize();
 label->move(10,10);
 collections=new QListBox(this,"collectionlist");
@@ -81,11 +81,11 @@ if (slman->numberOfCollections()>0)
     collections->centerCurrentItem();
     };
 //fillInSongList();
-newC=new QPushButton(i18n("New"),this);
+newC=new QPushButton(i18n("&New..."),this);
 newC->adjustSize();
 newC->move(360,collections->y()+5);
 connect(newC,SIGNAL(clicked()),SLOT(newCollection()) );
-copyC=new QPushButton(i18n("Copy"),this);
+copyC=new QPushButton(i18n("&Copy..."),this);
 copyC->adjustSize();
 copyC->move(360,newC->y()+newC->height()+5);
 connect(copyC,SIGNAL(clicked()),SLOT(copyCollection()) );
@@ -94,11 +94,11 @@ deleteC->adjustSize();
 deleteC->move(360,copyC->y()+copyC->height()+5);
 connect(deleteC,SIGNAL(clicked()),SLOT(deleteCollection()) );
 
-addS=new QPushButton(i18n("Add"),this);
+addS=new QPushButton(i18n("&Add..."),this);
 addS->adjustSize();
 addS->move(360,songs->y()+5);
 connect(addS,SIGNAL(clicked()),SLOT(addSong()) );
-delS=new QPushButton(i18n("Remove"),this);
+delS=new QPushButton(i18n("&Remove"),this);
 delS->adjustSize();
 delS->move(360,addS->y()+addS->height()+5);
 connect(delS,SIGNAL(clicked()),SLOT(removeSong()) );
@@ -114,7 +114,7 @@ void CollectionDialog::collectionselected(int idx)
 {
 selectedC=idx;
 #ifdef COLLECTDLGDEBUG
-printf("Selected collection : %d\n",selectedC);
+printf("Selected collection: %d\n",selectedC);
 #endif
 currentsl=slman->getCollection(selectedC);
 fillInSongList();
@@ -147,27 +147,26 @@ selectedS=idx;
 currentsl->setActiveSong(idx+1);
 
 #ifdef COLLECTDLGDEBUG
-printf("Selected song : %d\n",selectedS);
+printf("Selected song: %d\n",selectedS);
 #endif
 };
 
 void CollectionDialog::newCollection()
 {
-KAskDialog *dlg;
-dlg=new KAskDialog(i18n("Enter the name of the new collection"),
-			i18n("New Collection"),this,"kask");
-if (dlg->exec()==QDialog::Accepted)
-   {
-   int i=slman->createCollection(KAskDialog::getResult().ascii());
+  KLineEditDlg dlg(i18n("Enter the name of the new collection:"), QString::null, this);
+  dlg.setCaption(i18n("New Collection"));
+  if (dlg.exec())
+  {
+   int i=slman->createCollection(dlg.text().ascii());
    if (i==-1)
 	{
 	QString s = i18n("The name '%1' is already used")
-			.arg(KAskDialog::getResult());
+			.arg(dlg.text());
 	KMessageBox::sorry(this, s);
 	}
 	else
 	{
-	collections->insertItem(KAskDialog::getResult(),i);
+	collections->insertItem(dlg.text(),i);
 	collections->setCurrentItem(i);
         collections->centerCurrentItem();
 	};
@@ -177,22 +176,21 @@ if (dlg->exec()==QDialog::Accepted)
 void CollectionDialog::copyCollection()
 {
 SongList *src=currentsl;
-KAskDialog *dlg;
 int i;
-dlg=new KAskDialog(i18n("Enter the name of the copy collection"),
-			i18n("Copy Collection"),this,"kask");
-if (dlg->exec()==QDialog::Accepted)
-   {
-   i=slman->createCollection(KAskDialog::getResult().ascii());
+  KLineEditDlg dlg(i18n("Enter the name of the copy collection:"), QString::null, this);
+  dlg.setCaption(i18n("Copy Collection"));
+  if (dlg.exec())
+  {
+   i=slman->createCollection(dlg.text().ascii());
    if (i==-1)
 	{
 	QString s = i18n("The name '%1' is already used")
-			.arg(KAskDialog::getResult());
+			.arg(dlg.text());
 	KMessageBox::sorry(this, s);
 	}
 	else
 	{
-	collections->insertItem(KAskDialog::getResult(),i);
+	collections->insertItem(dlg.text(),i);
 	SongList *tgt=slman->getCollection(i);
 	src->iteratorStart();
 	while (!src->iteratorAtEnd())
@@ -219,21 +217,20 @@ collections->centerCurrentItem();
 void CollectionDialog::changeCollectionName(int idx)
 {
 if (idx==0) return;
-KAskDialog *dlg;
-dlg=new KAskDialog(i18n("Enter the new name for the selected collection"),
-			i18n("Change Collection Name"),this,"kask");
-if (dlg->exec()==QDialog::Accepted)
-   {
-   if (slman->getCollection(KAskDialog::getResult().ascii())!=NULL)
+  KLineEditDlg dlg(i18n("Enter the name of the selected collection:"), QString::null, this);
+  dlg.setCaption(i18n("Change Collection Name"));
+  if (dlg.exec())
+  {
+   if (slman->getCollection(dlg.text().ascii())!=NULL)
 	{
 	QString s = i18n("The name '%1' is already used")
-			.arg(KAskDialog::getResult());
+			.arg(dlg.text());
 	KMessageBox::sorry(this, s);
 	}
 	else
 	{
-	slman->changeCollectionName(idx,KAskDialog::getResult().ascii());
-	collections->changeItem(KAskDialog::getResult(),idx);
+	slman->changeCollectionName(idx,dlg.text().ascii());
+	collections->changeItem(dlg.text(),idx);
 	};
    };
 };
