@@ -35,6 +35,7 @@
 #include <kaccel.h>
 #include <kapplication.h>
 #include <kconfig.h>
+#include <kcmdlineargs.h>
 #include <kfiledialog.h>
 #include <kfontdialog.h>
 #include <kglobal.h>
@@ -112,7 +113,7 @@ kmidFrame::kmidFrame(const char *name)
     (void)new KAction(i18n("Forward"), "2rightarrow", 0, kmidclient,
 		SLOT(slotForward()), actionCollection(), "song_forward");  
 
-    (void)new KAction(i18n("&Organize ..."), 0, this, SLOT(collect_organize()),
+    (void)new KAction(i18n("&Organize..."), 0, this, SLOT(collect_organize()),
 		actionCollection(), "collect_organize");  
 
     QStringList playmodes;
@@ -124,11 +125,11 @@ kmidFrame::kmidFrame(const char *name)
     connect(act,SIGNAL(activated(int)),this, SLOT(collect_PlayOrder(int)));
     act->setItems(playmodes);  
 
-    (void)new KToggleAction(i18n("AutoAdd to Collection"), 0, this, 
+    (void)new KToggleAction(i18n("Auto-Add to Collection"), 0, this, 
 	SLOT(collect_AutoAdd()), actionCollection(), "collect_autoadd"); 
     
     playmodes.clear();
-    playmodes.append(i18n("&General Midi"));
+    playmodes.append(i18n("&General MIDI"));
     playmodes.append(i18n("&MT-32"));
     
     act=new KSelectAction(i18n("File Type"), 0,/* this, SLOT(options_FileType(int)),*/
@@ -158,19 +159,19 @@ kmidFrame::kmidFrame(const char *name)
 		0, this, SLOT(options_ShowChannelView()), actionCollection(),
 		"toggle_channelview");
 
-    (void)new KAction(i18n("Channel View &Options ..."), 0, this,
+    (void)new KAction(i18n("Channel View &Options..."), 0, this,
 		SLOT(options_ChannelViewOptions()), actionCollection(),
 		"channelview_options");
 
-    (void)new KAction(i18n("&Font Change ..."), 0, this,
+    (void)new KAction(i18n("&Font Change..."), 0, this,
 		SLOT(options_FontChange()), actionCollection(),
 		"change_font");
 
-    (void)new KAction(i18n("Configure &Keys ..."), 0, this,
+    (void)new KAction(i18n("Configure &Keys..."), 0, this,
 		SLOT(options_KeyConfig()), actionCollection(),
 		"configure_keys");
 
-    (void)new KAction(i18n("Midi &Setup ..."), 0, this,
+    (void)new KAction(i18n("MIDI &Setup..."), 0, this,
 		SLOT(options_MidiSetup()), actionCollection(), "midi_setup");
 
 
@@ -222,7 +223,9 @@ kmidFrame::kmidFrame(const char *name)
 //    connect( kmidclient, SIGNAL( channelView_Destroyed() ),
 //             this, SLOT( channelViewDestroyed() ) );
 
-    if ((kapp->argc()>1)&&(kapp->argv()[1][0]!='-'))
+    KCmdLineArgs * args = KCmdLineArgs::parsedArgs();
+
+    if ( args->count() > 0 )
     {
 //        printf("Opening command line file...\n");
         int backautoadd=cfg->readNumEntry("AutoAddToCollection",0);
@@ -230,13 +233,13 @@ kmidFrame::kmidFrame(const char *name)
         
         char ttt[40];
         sprintf(ttt,"%d",kapp->argc());
-        int i=1;
-        int c=autoAddSongToCollection((kapp->argv())[i],1);
+        int i=0;
+        int c=autoAddSongToCollection( args->url( 0 ).path() , 1 );
         i++;
-        while (i<kapp->argc()) 
+        while (i<args->count()) 
         {
-            autoAddSongToCollection((kapp->argv())[i],0);
-            i++;
+            autoAddSongToCollection( args->url( i ).path() , 0 );
+            i++; 
         }
         
         kmidclient->setActiveCollection(c);
@@ -252,6 +255,8 @@ kmidFrame::kmidFrame(const char *name)
         if (kmidclient->midiFileName()!=NULL) kmidclient->play();
         cfg->writeEntry("AutoAddToCollection",backautoadd);
     }
+    
+    args->clear();
         /*
          kKeys->addKey("Play/Pause",Key_Space);
          kKeys->registerWidget("KMidFrame",this);
