@@ -1,7 +1,7 @@
 /*
  *              KSCD -- a simpole cd player for the KDE project
  *
- * $Id: docking.cpp,v 1.8 2000/12/01 21:59:02 malte Exp $
+ * $Id: docking.cpp,v 1.9 2002/01/06 04:17:10 mueller Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -25,7 +25,7 @@
 #include "kmidiframe.h"
 
 #include <qtooltip.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "docking.h"
 #include <klocale.h>
