@@ -1,5 +1,5 @@
 /*
-	$Id: instrum.cpp,v 1.10 2001/01/19 09:17:50 coolo Exp $
+	$Id: instrum.cpp,v 1.11.6.1 2002/12/12 12:10:36 waba Exp $
 
     TiMidity -- Experimental MIDI to WAVE converter
     Copyright (C) 1995 Tuukka Toivonen <toivonen@clinet.fi>
@@ -32,11 +32,7 @@
 #include <strings.h>
 #endif
 
-#if defined(__FreeBSD__) || defined (__WIN32__) || defined(__bsdi__)
 #include <stdlib.h>
-#else
-#include <malloc.h>
-#endif
 
 #include "config.h"
 #include "common.h"
@@ -361,8 +357,8 @@ static InstrumentLayer *load_instrument(const char *name, int font_type, int per
 	{
 	  if (strlen(name)+strlen(patch_ext[i])<1024)
 	    {
-	      strcpy(tmpbuf, name);
-	      strcat(tmpbuf, patch_ext[i]);
+	      strlcpy(tmpbuf, name, sizeof(tmpbuf));
+	      strlcat(tmpbuf, patch_ext[i], sizeof(tmpbuf));
 	      if ((fp=open_file(tmpbuf, 1, OF_NORMAL, 0)))
 		{
 		  noluck=0;
