@@ -1,7 +1,7 @@
 /*
    kmidi
 
-   $Id: playlist.cpp,v 1.34 2002/01/06 04:17:10 mueller Exp $
+   $Id: playlist.cpp,v 1.39 2002/08/03 07:16:44 mhunter Exp $
 
    Copyright 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -28,6 +28,7 @@
 #include <qtextstream.h>
 
 #include <kconfig.h>
+#include <klineeditdlg.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
@@ -62,26 +63,13 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
   QPopupMenu *file = new QPopupMenu;
   Q_CHECK_PTR( file );
 
-  snpopup = new QFrame( this ,0, WType_Popup);
-  snpopup->setFrameStyle( QFrame::PopupPanel|QFrame::Raised );
-  snpopup->resize(170,75);
-
-  newEdit = new QLineEdit( snpopup, "_editnew" );
-
-  QLabel *labsavename = new QLabel(snpopup);
-  labsavename->setText(i18n("Enter new name"));
-  newEdit->setGeometry(10,10, 150, 30);
-  labsavename->setGeometry(20,10+30, 150, 30);
-  connect( newEdit, SIGNAL( returnPressed() ), this, SLOT( newPlaylist() ) );
-  newEdit->setFocus();
-
   file->insertItem( i18n("OK"), this, SLOT(checkList()), 0, 40);
 	file->setWhatsThis(40, i18n("Accept and use the new play list.") );
   file->insertItem( i18n("Save"), this, SLOT(saveIt()), 0, 41);
 	file->setWhatsThis(41, i18n("Replace the contents of the<br>\n"
 				"currently selected playlist<br>\n"
 				"file with the new play list.") );
-  file->insertItem( i18n("Save as ..."), this, SLOT( editNewPlaylist() ), 0, 42);
+  file->insertItem( i18n("Save As..."), this, SLOT( newPlaylist() ), 0, 42);
 	file->setWhatsThis(42, i18n("Make up a name for a<br>\n"
 				"new playlist file and<br>\n"
 				"save the current play list there.") );
@@ -91,16 +79,16 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
 				"playlist file.") );
   file->insertItem( i18n("Delete"), this, SLOT(removeIt()), 0, 44);
 	file->setWhatsThis(44, i18n("Delete the currently selected<br>\n"
-				"playlist file (it's contents<br>\n"
+				"playlist file (its contents<br>\n"
 				"will be lost).") );
   file->insertSeparator();
   file->insertItem( i18n("&Quit"), this, SLOT(hide()), 0, 45);
 	file->setWhatsThis(45, i18n("Discard the play list<br>\n"
-				"and leave the play list editor.") );
+				"and exit the play list editor.") );
 
   view = new QPopupMenu;
   Q_CHECK_PTR( view );
-  view->insertItem( i18n("All files"), this, SLOT(setFilter()), 0, 50 );
+  view->insertItem( i18n("All Files"), this, SLOT(setFilter()), 0, 50 );
 	view->setWhatsThis(50, i18n("Choose whether the file<br>\n"
 				"list should show only uncompressed<br>\n"
 				"midi files or all files.") );
@@ -110,12 +98,12 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
   edit->insertItem( i18n("Clear"), this, SLOT(clearPlist()), 0, 51 );
 	edit->setWhatsThis(51, i18n("Discard the contents<br>\n"
 				"of the current play list.") );
-  edit->insertItem( i18n("Select all"), this, SLOT(select_all()), 0, 52 );
+  edit->insertItem( i18n("Select All"), this, SLOT(select_all()), 0, 52 );
 	edit->setWhatsThis(52, i18n("Append all the files<br>\n"
 				"in the directory listing<br>\n"
 				"to the play list.") );
   edit->insertItem( i18n("Add"), this, SLOT(addEntry()), 0, 53 );
-	edit->setWhatsThis(53, i18n("Append the selected<br>\n"
+	edit->setWhatsThis(53, i18n("Append the selected file<br>\n"
 				"in the directory listing<br>\n"
 				"file to the play list.") );
   edit->insertItem( i18n("Remove"), this, SLOT(removeEntry()), 0, 54 );
@@ -128,7 +116,7 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
   menu->insertItem( i18n("&View"), view );
   menu->insertItem( i18n("&Edit"), edit );
   menu->insertSeparator();
-  menu->insertItem( i18n("What?"),  this, SLOT(invokeWhatsThis()) );
+  menu->insertItem( i18n("What's This?"),  this, SLOT(invokeWhatsThis()) );
 
 #if 0
   QString aboutapp;
@@ -571,22 +559,19 @@ void PlaylistEdit::checkList(){
 }
 
 
-void PlaylistEdit::editNewPlaylist(){
-    snpopup->move( QCursor::pos() );
-    snpopup->show();
-}
-
 void PlaylistEdit::newPlaylist(){
-	QString plf = newEdit->text();
-	snpopup->hide();
-	newEdit->clear();
-	plf += ".plist";
-        QString path = locateLocal("appdata", plf);
-	listsonglist->append(path);
-        listsonglist->sort();
-	*playlist_ptr = listsonglist->findIndex(path);
-	savePlaylistbyName(plf, true);
-	redoDisplay();
+	KLineEditDlg dlg(i18n("Enter name:"), QString::null, this);
+	dlg.setCaption(i18n("New Playlist"));
+	if (dlg.exec()) {
+	  QString plf = dlg.text();
+	  plf += ".plist";
+          QString path = locateLocal("appdata", plf);
+	  listsonglist->append(path);
+          listsonglist->sort();
+	  *playlist_ptr = listsonglist->findIndex(path);
+	  savePlaylistbyName(plf, true);
+	  redoDisplay();
+	}
 }
 
 
