@@ -194,6 +194,10 @@ KMixApplet::~KMixApplet()
    s_instCount--;
    if ( !s_instCount )
    {
+      QPtrListIterator<Mixer> it( *s_mixers );
+      for ( ; it.current(); ++it )
+         it.current()->release();
+
       s_mixers->clear();
       delete s_timer;
       delete s_mixers;
@@ -240,7 +244,7 @@ void KMixApplet::selectMixer()
 
    bool ok = FALSE;
    QString res = QInputDialog::getItem( i18n("Mixers"),
-                                        i18n("Available mixers"),
+                                        i18n("Available mixers:"),
 					lst, 1, FALSE, &ok, this );
    if ( ok )
    {
@@ -354,8 +358,7 @@ void KMixApplet::popupDirectionChange(Direction dir) {
   if (!m_errorLabel) {
     if (m_mixerWidget) delete m_mixerWidget;
     m_mixerWidget = new KMixerWidget( 0, mixer, mixerName, mixerNum, true,
-                                      checkReverse(dir),
-                                      this );
+                                      checkReverse(dir), this );
     m_mixerWidget->loadConfig( config(), "Widget" );
     setColors();
     connect( m_mixerWidget, SIGNAL(updateLayout()), this, SLOT(triggerUpdateLayout()));
