@@ -20,6 +20,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <kaction.h>
 #include <klocale.h>
 #include <kapplication.h>
 #include <kpanelapplet.h>
@@ -39,9 +40,10 @@
 
 KMixDockWidget::KMixDockWidget( Mixer *mixer,
 				QWidget *parent, const char *name )
-    : KSystemTray( parent, name ), m_mixer(mixer), masterVol(0L)
+    : KSystemTray( parent, name ), m_mixer(mixer), masterVol(0L), m_mixerVisible(false)
 {
     createMasterVolWidget();
+    connect(this, SIGNAL(quitSelected()), kapp, SLOT(quit()));
 }
 
 KMixDockWidget::~KMixDockWidget()
@@ -75,8 +77,23 @@ void KMixDockWidget::createMasterVolWidget()
 
 void KMixDockWidget::setVolumeTip(int, Volume vol)
 {
+    MixDevice *masterDevice = ( *m_mixer )[ m_mixer->masterDevice() ];
+    QString tip = i18n("Volume at %1%").arg(vol.getVolume(0));
+    if ( masterDevice->isMuted() )
+        tip += i18n( " (Muted)" );
+
     QToolTip::remove(this);
-    QToolTip::add(this, i18n("Volume at %1%").arg(vol.getVolume(0)));
+    QToolTip::add(this, tip);
+}
+
+void KMixDockWidget::updatePixmap()
+{
+    MixDevice *masterDevice = ( *m_mixer )[ m_mixer->masterDevice() ];
+
+    if ( masterDevice->isMuted() )
+        setPixmap( BarIcon( "kmixdocked_mute" ) );
+    else
+        setPixmap( BarIcon( "kmixdocked" ) );
 }
 
 void KMixDockWidget::mousePressEvent(QMouseEvent *me)
@@ -101,7 +118,7 @@ void KMixDockWidget::mouseReleaseEvent(QMouseEvent *me)
         // If left-click, toggle the master volume control.
         switch ( me->button() ) {
     		case LeftButton:
-        		if (!masterVol->isVisible()) {
+        		if (!m_mixerVisible) {
 			int scnum = QApplication::desktop()->screenNumber(this);
             		QRect desktop = QApplication::desktop()->screenGeometry(scnum);
             		int sw = desktop.width();
@@ -128,11 +145,12 @@ void KMixDockWidget::mouseReleaseEvent(QMouseEvent *me)
         		} else {
             		masterVol->hide();          // fixme: this doesn't work?!
         		}
+                m_mixerVisible = !m_mixerVisible;
         		QWidget::mouseReleaseEvent(me); // KSystemTray's shouldn't do the default action for this 
         		return;
     		default:
-        		masterVol->hide();
-        		KSystemTray::mouseReleaseEvent(me);
+        		//masterVol->hide();
+        		//KSystemTray::mouseReleaseEvent(me);
         		return;
         }
     }
@@ -141,6 +159,7 @@ void KMixDockWidget::mouseReleaseEvent(QMouseEvent *me)
 
 void KMixDockWidget::wheelEvent(QWheelEvent *e)
 {
+    m_mixerVisible = masterVol->isVisible();
     MixDevice *masterDevice = (*m_mixer)[m_mixer->masterDevice()];
     Volume vol = masterDevice->getVolume();
     int inc = vol.maxVolume() / 20;
@@ -149,6 +168,7 @@ void KMixDockWidget::wheelEvent(QWheelEvent *e)
  
     for ( int i = 0; i < vol.channels(); i++ ) {
         int newVal = vol[i] + (inc * (e->delta() / 120));
+	if( newVal < 0 ) newVal = 0;
         vol.setVolume( i, newVal < vol.maxVolume() ? newVal : vol.maxVolume() );
     }
     
@@ -157,15 +177,20 @@ void KMixDockWidget::wheelEvent(QWheelEvent *e)
     setVolumeTip(masterDevice->num(), vol);
 }
 
-void KMixDockWidget::contextMenuAboutToShow( KPopupMenu* menu )
+void KMixDockWidget::contextMenuAboutToShow( KPopupMenu* /* menu */ )
 {
-    for ( unsigned n=0; n<menu->count(); n++ )
+    KAction* showAction = actionCollection()->action("minimizeRestore");
+    if ( parentWidget() && showAction ) 
     {
-        if ( QString( menu->text( menu->idAt(n) ) )==i18n("&Quit") )
-            menu->removeItemAt( n );
+        if ( parentWidget()->isVisible() )
+        {
+            showAction->setText( i18n("Hide Mixer Window") );
+        }
+        else
+        {
+            showAction->setText( i18n("Show Mixer Window") );
+        }
     }
-
-    menu->insertItem( SmallIcon("exit"), i18n("&Quit" ), kapp, SLOT(quit()) );
 }
 
 #include "kmixdockwidget.moc"
