@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <iostream.h>
+#include <iostream>
 #include <stdlib.h>
 
 #include <qcursor.h>
@@ -28,6 +28,7 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qslider.h>
+#include <qtimer.h>
 #include <qtooltip.h>
 #include <qgroupbox.h>
 #include <qcheckbox.h>
@@ -70,7 +71,8 @@ KMixerWidget::KMixerWidget( int _id, Mixer *mixer, QString mixerName, int mixerN
 
 {
    m_actions = new KActionCollection( this );
-   new KAction( i18n("Show &all"), 0, this, SLOT(showAll()), m_actions, "show_all" );
+   new KAction( i18n("Show &All"), 0, this, SLOT(showAll()), m_actions, "show_all" );
+
    m_channels.setAutoDelete( true );
    m_small = small;
 
@@ -116,8 +118,11 @@ void KMixerWidget::createDeviceWidgets( KPanelApplet::Direction dir )
    for ( ; mixDevice != 0; mixDevice = mixSet.next())
    {
       MixDeviceWidget *mdw =
-         new MixDeviceWidget( m_mixer, mixDevice, !m_small, !m_small, m_small,
-                              m_direction, this, mixDevice->name().latin1() );
+	new MixDeviceWidget( m_mixer, mixDevice, !m_small, !m_small, m_small,
+			     m_direction, this, mixDevice->name().latin1() );
+
+      connect( mdw, SIGNAL( masterMuted( bool ) ),
+                  SIGNAL( masterMuted( bool ) ) );
 
       connect( mdw, SIGNAL(updateLayout()), this, SLOT(updateSize()));
       m_devLayout->addWidget( mdw, 0 );
@@ -139,6 +144,10 @@ void KMixerWidget::createDeviceWidgets( KPanelApplet::Direction dir )
       m_topLayout->addWidget( m_balanceSlider );
       connect( m_balanceSlider, SIGNAL(valueChanged(int)), m_mixer, SLOT(setBalance(int)) );
       QToolTip::add( m_balanceSlider, i18n("Left/Right balancing") );
+
+      QTimer *updateTimer = new QTimer( this );
+      connect( updateTimer, SIGNAL(timeout()), this, SLOT(updateBalance()) );
+      updateTimer->start( 200, FALSE );
    } else
       m_balanceSlider = 0;
 
@@ -197,6 +206,14 @@ void KMixerWidget::mousePressEvent( QMouseEvent *e )
       rightMouseClicked();
 }
 
+void KMixerWidget::addActionToPopup( KAction *action ) {
+  m_actions->insert( action );
+
+  for ( Channel *chn=m_channels.first(); chn!=0; chn=m_channels.next() ) {
+    chn->dev->addActionToPopup( action );
+  }
+}
+
 void KMixerWidget::rightMouseClicked()
 {
    KPopupMenu *menu = new KPopupMenu( this );
@@ -205,6 +222,9 @@ void KMixerWidget::rightMouseClicked()
    KAction *a = m_actions->action( "show_all" );
    if ( a ) a->plug( menu );
 
+   a = m_actions->action( "options_show_menubar" );
+   if ( a ) a->plug( menu );
+   
    QPoint pos = QCursor::pos();
    menu->popup( pos );
 }
@@ -278,4 +298,25 @@ void KMixerWidget::showAll()
    updateSize();
 }
 
+void KMixerWidget::updateBalance()
+{
+  MixDevice *md = m_mixer->mixDeviceByType( 0 );
+  if (!md) return;
+  int right= md->rightVolume();
+  int left = md->leftVolume();
+  
+  int value = 0;
+  if ( left != right ) {
+    int refvol = left > right ? left : right;
+    if (left > right)
+      value = (100*right) / refvol - 100;
+    else
+      value = -((100*left) / refvol - 100);
+  } 
+  m_balanceSlider->blockSignals( true );
+  m_balanceSlider->setValue( value );
+  m_balanceSlider->blockSignals( false );  
+}
+
+
 #include "kmixerwidget.moc"
