@@ -48,6 +48,8 @@ class KMixerWidget : public QWidget  {
                  QWidget *parent=0, const char *name=0 );
    ~KMixerWidget();
 
+   void addActionToPopup( KAction *action );
+
    QString name() { return m_name; };
    void setName( QString name ) { m_name = name; };
 
@@ -63,6 +65,7 @@ class KMixerWidget : public QWidget  {
 
   signals:
    void updateLayout();
+   void masterMuted( bool );
 
   public slots:     
    void setTicks( bool on );
@@ -77,6 +80,7 @@ class KMixerWidget : public QWidget  {
 
   private slots:	
    void rightMouseClicked();	
+   void updateBalance();
    void updateSize();
 
   private:
