@@ -20,59 +20,49 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <iostream.h>
-
-#include <qwidget.h>
-#include <qtabdialog.h>
 #include <qlayout.h>
 #include <qwhatsthis.h>
 
 #include <klocale.h>
-#include <kdialog.h>
 
 #include "kmix.h"
 #include "kmixprefdlg.h"
 #include "kmixerwidget.h"
 
 
-KMixPrefDlg::KMixPrefDlg()
+KMixPrefDlg::KMixPrefDlg( QWidget *parent )
+    : KDialogBase(  Plain, i18n( "KMix Preferences" ),
+          Ok|Cancel|Apply, Ok, parent )
 {
-   setCaption( i18n("KMix Preferences") );
-
    // general buttons
-   m_generalTab = new QWidget( this );
+   m_generalTab = plainPage( /* i18n("&General") */ );
+
    QBoxLayout *layout = new QVBoxLayout( m_generalTab );
-     layout->setSpacing( KDialog::spacingHint() );
-    layout->setMargin( KDialog::marginHint() );
+   layout->setSpacing( KDialog::spacingHint() );
 
    m_dockingChk = new QCheckBox( i18n("&Dock into panel"), m_generalTab );
    layout->addWidget( m_dockingChk );
    QWhatsThis::add(m_dockingChk, i18n("Docks the mixer into the KDE panel"));
 
-   m_volumeChk = new QCheckBox(i18n("Enable System Tray &volume control"),
+   m_volumeChk = new QCheckBox(i18n("Enable system tray &volume control"),
 			       m_generalTab);
    layout->addWidget(m_volumeChk);
 
-// commented this out. From the usability point of view, this option makes absolutely no sense. nolden
-//   m_hideOnCloseChk = new QCheckBox( i18n("Only &hide window with close button"), m_generalTab );
-//   layout->addWidget( m_hideOnCloseChk );
-
    m_showTicks = new QCheckBox( i18n("Show &tickmarks"), m_generalTab );
    layout->addWidget( m_showTicks );
-  QWhatsThis::add(m_showTicks, i18n("Enable/disable tickmark scales on the sliders"));
+   QWhatsThis::add(m_showTicks, 
+           i18n("Enable/disable tickmark scales on the sliders"));
 
    m_showLabels = new QCheckBox( i18n("Show &labels"), m_generalTab );
    layout->addWidget( m_showLabels );
-   QWhatsThis::add(m_showLabels, i18n("Enables/disables description labels above the sliders"));
+   QWhatsThis::add(m_showLabels, 
+           i18n("Enables/disables description labels above the sliders"));
 
-   addTab( m_generalTab, i18n("&General") );
+   layout->addStretch();
+   enableButtonSeparator(true);
 
-   // dialog buttons
-   setCancelButton( i18n("&Cancel") );
-   setOkButton( i18n("&OK") );
-   setApplyButton( i18n("&Apply") );
-
-   connect( this, SIGNAL(applyButtonPressed()), this, SLOT(apply()) );
+   connect( this, SIGNAL(applyClicked()), this, SLOT(apply()) );
+   connect( this, SIGNAL(okClicked()), this, SLOT(apply()) );
 }
 
 KMixPrefDlg::~KMixPrefDlg()
@@ -81,7 +71,6 @@ KMixPrefDlg::~KMixPrefDlg()
 
 void KMixPrefDlg::apply()
 {
-   cerr << "KMixPrefDlg::apply()" << endl;
    emit signalApplied( this );
 }
 
