@@ -25,11 +25,11 @@
 #include <kled.h>
 #include <kiconloader.h>
 #include <kconfig.h>
-#include <kdebug.h>
 #include <kaction.h>
 #include <kpopupmenu.h>
 #include <kglobalaccel.h>
 #include <kkeydialog.h>
+#include <kdebug.h>
 
 #include <qcursor.h>
 #include <qslider.h>
@@ -40,8 +40,6 @@
 #include <qtimer.h>
 #include <qwmatrix.h>
 
-#include <iostream.h>
-
 #include "mixer.h"
 #include "mixdevicewidget.h"
 #include "kledbutton.h"
@@ -77,8 +75,9 @@ MixDeviceWidget::MixDeviceWidget(Mixer *mixer, MixDevice* md,
    KToggleAction *a = new KToggleAction( i18n("&Muted"), 0, 0, 0, m_actions, "mute" );
    a->connect( a, SIGNAL(toggled(bool)), this, SLOT(setMuted(bool)) );
 
-   if (parent->isA("KMixerWidget"))
-       new KAction( i18n("Show &All"), 0, parent, SLOT(showAll()), m_actions, "show_all" );
+   if (parent->isA("KMixerWidget")) {
+     new KAction( i18n("Show &All"), 0, parent, SLOT(showAll()), m_actions, "show_all" );
+   }
 
    if( m_mixdevice->isRecordable() )
    {
@@ -86,7 +85,7 @@ MixDeviceWidget::MixDeviceWidget(Mixer *mixer, MixDevice* md,
       a->connect( a, SIGNAL(toggled(bool)), this, SLOT(setRecsrc(bool)) );
    }
 
-   new KAction( i18n("Define &Keys"), 0, this, SLOT(defineKeys()), m_actions, "keys" );
+   new KAction( i18n("Define &Keys..."), 0, this, SLOT(defineKeys()), m_actions, "keys" );
 
    // create widgets
    createWidgets( showMuteLED, showRecordLED );
@@ -97,11 +96,11 @@ MixDeviceWidget::MixDeviceWidget(Mixer *mixer, MixDevice* md,
    m_updateTimer->start( 200, FALSE );
 
    m_keys = new KGlobalAccel( this, "Keys" );
-   m_keys->insert( "Increase volume", i18n( "Increase volume" ), QString::null,
+   m_keys->insert( "Increase volume", i18n( "Increase Volume" ), QString::null,
       KShortcut(), KShortcut(), this, SLOT( increaseVolume() ) );
-   m_keys->insert( "Decrease volume", i18n( "Decrease volume" ), QString::null,
+   m_keys->insert( "Decrease volume", i18n( "Decrease Volume" ), QString::null,
       KShortcut(), KShortcut(), this, SLOT( decreaseVolume() ) );
-   m_keys->insert( "Toggle mute", i18n( "Toggle mute" ), QString::null,
+   m_keys->insert( "Toggle mute", i18n( "Toggle Mute" ), QString::null,
       KShortcut(), KShortcut(), this, SLOT( toggleMuted() ) );
    // No need for m_keys->readSettings(), the keys are loaded in KMixerWidget::loadConfig, see kmixerwidget.cpp
    m_keys->updateConnections();
@@ -112,6 +111,11 @@ MixDeviceWidget::~MixDeviceWidget()
 }
 
 
+void MixDeviceWidget::addActionToPopup( KAction *action ) {
+  m_actions->insert( action );
+}
+
+
 #define GET_NEWLAYOUT(x) \
 	QBoxLayout *x; \
 	if ((m_direction == KPanelApplet::Up) || (m_direction == KPanelApplet::Down)) \
@@ -184,7 +188,7 @@ void MixDeviceWidget::createWidgets( bool showMuteLED, bool showRecordLED )
       m_sliders.append ( slider );
       connect( slider, SIGNAL(valueChanged(int)), this, SLOT(volumeChange(int)) );
    }
-   
+
    // create channel icon
    if ((m_direction == KPanelApplet::Right) || (m_direction == KPanelApplet::Down)) {
       m_iconLabel = 0L;
@@ -245,6 +249,12 @@ QPixmap MixDeviceWidget::getIcon( int icon )
          miniDevPM = UserIcon("mix_video"); break;
       case MixDevice::SURROUND:
          miniDevPM = UserIcon("mix_surround"); break;
+		case MixDevice::HEADPHONE:
+			miniDevPM = UserIcon( "mix_headphone" ); break;
+		case MixDevice::DIGITAL:
+			miniDevPM = UserIcon( "mix_digital" ); break;
+		case MixDevice::AC97:
+			miniDevPM = UserIcon( "mix_ac97" ); break;
       default:
          miniDevPM = UserIcon("mix_unknown"); break;
    }
@@ -275,7 +285,7 @@ void MixDeviceWidget::setIcon( int icon )
       m_iconLabel->setAlignment( Qt::AlignCenter );
    } else
    {
-      cerr << "Pixmap missing.\n";
+      kdDebug() << "Pixmap missing." << endl;
    }
 
    layout()->activate();
@@ -311,6 +321,9 @@ void MixDeviceWidget::setMuted(bool value)
    m_mixdevice->setMuted( value );
    update();
    emit newVolume( m_mixdevice->num(), m_mixdevice->getVolume() );
+
+   if ( m_mixdevice->num()==m_mixer->masterDevice() )
+       emit masterMuted( value );
 }
 
 void MixDeviceWidget::toggleMuted()
@@ -373,7 +386,7 @@ void MixDeviceWidget::setTicks( bool ticks )
 
 void MixDeviceWidget::setIcons(bool value)
 {
-   if ( ( !m_iconLabel->isHidden()) !=value ) 
+   if ( ( !m_iconLabel->isHidden()) !=value )
    {
       if (value)
          m_iconLabel->show();
@@ -611,6 +624,8 @@ void MixDeviceWidget::contextMenu()
 
    a = m_actions->action( "show_all" );
    if ( a ) a->plug( menu );
+   a = m_actions->action( "options_show_menubar" );
+   if ( a ) a->plug( menu );
 
    QPoint pos = QCursor::pos();
    menu->popup( pos );
