@@ -57,6 +57,8 @@ class MixDeviceWidget
                        QWidget* parent = 0, const char* name = 0);
       ~MixDeviceWidget();
 
+      void addActionToPopup( KAction *action );
+
       bool isDisabled();
       bool isMuted();
       bool isRecsrc();
@@ -81,8 +83,10 @@ class MixDeviceWidget
       void setDisabled( bool value );
 
       void defineKeys();
+
    signals:
       void newVolume( int num, Volume volume );
+      void masterMuted( bool );
       void newRecsrc( int num, bool on );
       void updateLayout();
       void rightMouseClick();
