@@ -2,8 +2,8 @@
  *              KMix -- KDE's full featured mini mixer
  *
  *
- *              Copyright (C) 1996-2000 Christian Esken
- *                        esken@kde.org
+ * Copyright (C) 1996-2000 Christian Esken - esken@kde.org
+ * 2002 Helio Chissini de Castro - helio@conectiva.com.br
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,11 +20,11 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <iostream.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <kdebug.h>
+#include <dcopobject.h>
 
 #include "mixer.h"
 #include "kmix-platforms.cpp"
@@ -138,7 +138,8 @@ int Mixer::getDriverNum()
 {
     MixerFactory *factory = g_mixerFactories;
     int num = 0;
-    while( factory->getMixer!=0 ) {
+    while( factory->getMixer!=0 ) 
+	 {
         num++;
         factory++;
     }
@@ -167,7 +168,7 @@ Mixer* Mixer::getMixer( int driver, MixSet set,int device, int card )
 }
 
 
-Mixer::Mixer( int device, int card )
+Mixer::Mixer( int device, int card ) : DCOPObject( "Mixer" )
 {
   m_devnum = device;
   m_cardnum = card;
@@ -179,6 +180,11 @@ Mixer::Mixer( int device, int card )
   m_mixDevices.setAutoDelete( true );
   m_profiles.setAutoDelete( true );
   m_mixerNum = 0;
+
+  QCString objid;
+  objid.setNum(m_devnum);
+  objid.prepend("Mixer");
+  DCOPObject::setObjId( objid );
 };
 
 int Mixer::setupMixer( MixSet mset )
@@ -392,4 +398,91 @@ void Mixer::setRecsrc( int devnum, bool on )
         if( md->num() == devnum ) md->setRecsrc( on );
 }
 
+
+MixDevice *Mixer::mixDeviceByType( int deviceidx )
+{
+  unsigned int i=0;
+  while (i<size() && (*this)[i]->num()!=deviceidx) i++;
+  if (i==size()) return 0;
+ 
+  return (*this)[i];
+}
+
+void Mixer::setVolume( int deviceidx, int percentage )
+{
+  MixDevice *mixdev= mixDeviceByType( deviceidx );
+  if (!mixdev) return;
+  
+  Volume vol=mixdev->getVolume();
+  vol.setAllVolumes( (percentage*vol.maxVolume())/100 );
+  writeVolumeToHW(deviceidx, vol);
+}
+
+void Mixer::setMasterVolume( int percentage )
+{
+  setVolume( 0, percentage );
+}
+
+int Mixer::volume( int deviceidx )
+{
+  MixDevice *mixdev= mixDeviceByType( deviceidx );
+  if (!mixdev) return 0;
+  
+  Volume vol=mixdev->getVolume();
+  return (vol.getVolume( Volume::LEFT )*100)/vol.maxVolume();
+}
+
+int Mixer::masterVolume()
+{
+  return volume( 0 );
+}
+
+void Mixer::increaseVolume( int deviceidx )
+{
+  int vol=volume(deviceidx);
+  setVolume(deviceidx, vol+5);
+}
+
+void Mixer::decreaseVolume( int deviceidx )
+{
+  int vol=volume(deviceidx);
+  setVolume(deviceidx, vol-5);
+}
+
+void Mixer::setMute( int deviceidx, bool on )
+{
+  MixDevice *mixdev= mixDeviceByType( deviceidx );
+  if (!mixdev) return;
+
+  mixdev->setMuted( on ); 
+
+  writeVolumeToHW(deviceidx, mixdev->getVolume() );
+}
+
+bool Mixer::mute( int deviceidx )
+{
+  MixDevice *mixdev= mixDeviceByType( deviceidx );
+  if (!mixdev) return true;
+  
+  return mixdev->isMuted();
+}
+
+void Mixer::setRecordSource( int deviceidx, bool on )
+{
+  setRecsrc( deviceidx, on ); 
+}
+
+bool Mixer::isRecordSource( int deviceidx )
+{
+  MixDevice *mixdev= mixDeviceByType( deviceidx );
+  if (!mixdev) return false;
+  
+  return mixdev->isRecsrc();
+}
+
+bool Mixer::isAvailableDevice( int deviceidx )
+{
+  return mixDeviceByType( deviceidx );
+}
+
 #include "mixer.moc"
