@@ -4,8 +4,9 @@
  *
  *
  * Copyright (C) 2000 Stefan Schimanski <1Stein@gmx.de>
- *		 1996-2000 Christian Esken <esken@kde.org>
- *        		   Sven Fischer <herpes@kawo2.rwth-aachen.de>
+ * 1996-2000 Christian Esken <esken@kde.org>
+ * Sven Fischer <herpes@kawo2.rwth-aachen.de>
+ * 2002 - Helio Chissini de Castro <helio@conectiva.com.br>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -31,6 +32,7 @@
 #include <qptrlist.h>
 
 #include "volume.h"
+#include "mixerIface.h"
 
 /*
   I am using a fixed MAX_MIXDEVS #define here.
@@ -55,7 +57,7 @@ class MixDevice
       // For each ChannelType a special icon exists
       enum ChannelType {AUDIO = 1, BASS, CD, EXTERNAL, MICROPHONE,
 			MIDI, RECMONITOR, TREBLE, UNKNOWN, VOLUME,
-			VIDEO, SURROUND};
+			VIDEO, SURROUND, HEADPHONE, DIGITAL, AC97 };
 
       MixDevice(int num, Volume vol, bool recordable,
 		QString name, ChannelType type = UNKNOWN );
@@ -110,7 +112,7 @@ class MixSet : public QPtrList<MixDevice>
 };
 
 
-class Mixer : public QObject
+class Mixer : public QObject, virtual public MixerIface
 {
       Q_OBJECT
 
@@ -135,6 +137,11 @@ class Mixer : public QObject
       /// Returns a pointer to the mix device with the given number
       MixDevice* operator[](int val_i_num);
 
+      /// Returns a pointer to the mix device whose type matches the value
+      /// given by the parameter and the array MixerDevNames given in
+      /// mixer_oss.cpp (0 is Volume, 4 is PCM, etc.) 
+      MixDevice *mixDeviceByType( int deviceidx );
+
       /// Grabs (opens) the mixer for further intraction
       virtual int grab();
       /// Releases (closes) the mixer
@@ -145,7 +152,7 @@ class Mixer : public QObject
       /// Derived classes can override this method to produce platform
       /// specific error descriptions.
       virtual QString errorText(int mixer_error);
-      QString mixerName();
+      virtual QString mixerName();
 
       /// set/get mixer number used to identify mixers with equal names
       void setMixerNum( int num );
@@ -173,6 +180,23 @@ class Mixer : public QObject
       virtual int readVolumeFromHW( int devnum, Volume &vol ) = 0;
 
 
+      /// DCOP oriented methods (look at mixerIface.h for the descriptions)
+      virtual void setVolume( int channeltype, int percentage );
+      virtual void setMasterVolume( int percentage );
+
+      virtual void increaseVolume( int channeltype );
+      virtual void decreaseVolume( int channeltype );
+
+      virtual int volume( int channeltype );
+      virtual int masterVolume();
+
+      virtual void setMute( int channeltype, bool on );
+      virtual bool mute( int channeltype );
+      virtual void setRecordSource( int deviceidx, bool on );
+      virtual bool isRecordSource( int deviceidx );
+
+      virtual bool isAvailableDevice( int deviceidx );
+      
    public slots:
       /// Writes the given volumes in the given device
       /// Abstract method! You must implement it in your dericved class.
