@@ -6,7 +6,7 @@
  *      --- This file has been manually midified ---
  *
  *
- * $Id: CDDialog.cpp,v 1.56 2002/03/20 05:25:32 aseigo Exp $
+ * $Id: CDDialog.cpp,v 1.63 2002/10/07 02:21:52 aseigo Exp $
  *
  ***********************************************************************/
 
@@ -22,6 +22,7 @@
 #include <qdir.h>
 #include <qfileinfo.h> 
 #include <qlistview.h>
+#include <qlineedit.h>
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -275,7 +276,7 @@ CDDialog::extIB()
 
   InexactDialog *dialog;
   dialog = new InexactDialog(0,"dialog",false);
-  dialog->setTitle(i18n("Use this editor to annotate this track"));
+  dialog->setTitle(i18n("Use this editor to annotate this track."));
 
   dialog->insertText(*ext_list.at(iNr + 1));
   
@@ -299,7 +300,7 @@ CDDialog::extITB()
   InexactDialog *dialog;
   dialog = new InexactDialog(0,"dialog",false);
   dialog->insertText(ext_list.first());
-  dialog->setTitle(i18n("Use this editor to annotate the title"));
+  dialog->setTitle(i18n("Use this editor to annotate the title."));
   
   if(dialog->exec() != QDialog::Accepted)
     {
@@ -377,7 +378,7 @@ void CDDialog::titlechanged() {
 
 QString submitcat;
 
-void 
+void
 CDDialog::upload()
 {
   if(!checkit())
@@ -390,7 +391,7 @@ CDDialog::upload()
 	{
 	  dialog->insertList(catlist);
 	  dialog->setErrorString(i18n("Please select a category or press Cancel"));
-	  dialog->setTitle(i18n("To which category does the CD belong?"));
+	  dialog->setTitle(i18n("To Which Category does the CD Belong?"));
 	  if(dialog->exec() != QDialog::Accepted)
 		{
 		  delete dialog;
@@ -448,7 +449,7 @@ CDDialog::upload()
       
   QString cmd;
 
-  cmd = "/usr/sbin/sendmail -tU";
+  cmd = "/usr/sbin/sendmail -t";
 
   kdDebug() << "Submitting freedb entry: " << cmd << "\n" << endl;
   
@@ -519,36 +520,41 @@ void
 CDDialog::save()
 {
   if(!checkit())
+  {
+    emit dialog_done();
     return;
+  }
 
   QString savecat;
 
-  InexactDialog *dialog;
-  dialog = new InexactDialog(0,"Dialog",true);
-
   if( category.length() < 1 )
-	{
-	  dialog->insertList(catlist);
-	  dialog->setErrorString(i18n("Please select a category or press Cancel"));
-	  dialog->setTitle(i18n("Under which category would you like to store this disc's information?"));
-	  
-	  if(dialog->exec() != QDialog::Accepted)
-		{
-		  delete dialog;
-		  return;
-		}
-	  
-	  dialog->getSelection(savecat);
-	} else {
-	  savecat = category.copy();
-	}
+  {
+    InexactDialog *dialog;
+    dialog = new InexactDialog(0,"Dialog",true);
+    dialog->insertList(catlist);
+    dialog->setErrorString(i18n("Please select a category or press Cancel"));
+    dialog->setTitle(i18n("Under Which Category Would you like to Store this Disc's Information?"));
+
+    if(dialog->exec() != QDialog::Accepted)
+    {
+      delete dialog;
+      emit dialog_done();
+      return;
+    }
+
+    dialog->getSelection(savecat);
+    delete dialog;
+  } 
+  else 
+  {
+    savecat = category.copy();
+  }
 
   QString mag;
-  mag.sprintf("%s%s/%08lx",cddbbasedir.utf8().data(),savecat.utf8().data(),cdinfo.magicID);
+  mag.sprintf("%s/%s/%08lx",cddbbasedir.utf8().data(),savecat.utf8().data(),cdinfo.magicID);
 
   save_cddb_entry(mag,false);
   load_cddb();
-  delete dialog;
   emit dialog_done();
 } // save
 
@@ -587,7 +593,7 @@ CDDialog::save_cddb_entry(QString& path,bool upload)
   if( !file.open( IO_WriteOnly  )) 
     {
       QString str = i18n("Unable to write to file:\n%1\nPlease check "
-			 "your permissions and make your category directories exist.")
+			 "your permissions and ensure your category directories exist.")
 	.arg(path);
 
       KMessageBox::error(this, str);
@@ -804,7 +810,7 @@ CDDialog::checkit()
   if(track_list.count() < 2)
     {
       KMessageBox::sorry(this,
-			 i18n("Not all track titles can be empty.\n"\
+			 i18n("At least one track title must be entered.\n"\
 			      "Please correct the entry and try again."),
 			 i18n("Invalid Database Entry"));
       return false;
@@ -827,7 +833,7 @@ CDDialog::checkit()
     {
       
       KMessageBox::sorry(this,
-			 i18n("Not all track titles can be empty.\n"\
+			 i18n("At least one track title must be entered.\n"\
 			      "Please correct the entry and try again."),
 			 i18n("Invalid Database Entry"));
       return false;
