@@ -1,7 +1,7 @@
 #ifndef WM_CONFIG_H
 #define WM_CONFIG_H
 /*
- * $Id: wm_config.h,v 1.9.4.1 2002/04/20 11:44:39 espie Exp $
+ * $Id: wm_config.h,v 1.12 2002/11/05 04:42:08 aseigo Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -128,12 +128,31 @@
  ***  ******  **  **  ******  ******  **  ******  **  *  **********
  ***  ******  **  **      **      **     ****    ***    ***********
  ******************************************************************/
-#if defined(__FreeBSD__) || defined(__FreeBSD) || defined(__NetBSD__) || defined(__NetBSD)
+#if defined(__FreeBSD__) || defined(__FreeBSD)
 
-#define DEFAULT_CD_DEVICE	"/dev/rmatcd0c"
+#define DEFAULT_CD_DEVICE	"/dev/rcd0c"
 
 #endif /* freebsd */
 
+/******************************************************************
+ * NetBSD
+ ******************************************************************
+ ***   ***  **      **      **     ****    ***    *****************
+ ***    **  **  ********  ****  **  **  ******  *  ****************
+ ***  *  *  **    ******  ****    ******  ****  **  ***************
+ ***  **    **  ********  ****  **  ******  **  *  ****************
+ ***  ***   **      ****  ****     ****    ***    *****************
+ ******************************************************************/
+#if defined(__NetBSD__) || defined(__NetBSD)
+
+#if defined(__i386__)
+	#define DEFAULT_CD_DEVICE	"/dev/rcd0d"
+#else
+	#define DEFAULT_CD_DEVICE	"/dev/rcd0c"
+#endif
+
+#endif /* netbsd */
+
 /******************************************************************
  * HP-UX
  ******************************************************************
