@@ -1,5 +1,5 @@
 /*
- * $Id: plat_hpux.c,v 1.6 2001/01/30 05:56:20 dfoerste Exp $
+ * $Id: plat_hpux.c,v 1.7 2001/04/10 17:34:52 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * HP/UX-specific drive control routines.
  */
 
-static char plat_hpux_id[] = "$Id: plat_hpux.c,v 1.6 2001/01/30 05:56:20 dfoerste Exp $";
+static char plat_hpux_id[] = "$Id: plat_hpux.c,v 1.7 2001/04/10 17:34:52 dfoerste Exp $";
 
 #if defined(hpux) || defined(__hpux)
 
@@ -53,6 +53,7 @@ static char plat_hpux_id[] = "$Id: plat_hpux.c,v 1.6 2001/01/30 05:56:20 dfoerst
 
 #include "include/wm_struct.h"
 #include "include/wm_helpers.h"
+#include "include/wm_cdtext.h"
 
 #define WM_MSG_CLASS WM_MSG_CLASS_PLATFORM
 
@@ -340,6 +341,18 @@ gen_get_volume( struct wm_drive *d, int *left, int *right )
   return (wm_scsi2_get_volume(d, left, right));
 } /* gen_get_volume() */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  /* This needs to be tested ! */
+  return wm_scsi_get_cdtext(d, pp_buffer, p_buffer_lenght);
+} /* gen_get_cdtext() */
+
+
 #endif
 
 
