@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.16 2001/09/24 08:49:02 dfoerste Exp $
+ * $Id: plat_linux.c,v 1.17 2002/11/16 23:12:48 waba Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Linux-specific drive control routines.  Very similar to the Sun module.
  */
 
-static char plat_linux_id[] = "$Id: plat_linux.c,v 1.16 2001/09/24 08:49:02 dfoerste Exp $";
+static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17 2002/11/16 23:12:48 waba Exp $";
 
 #if defined(__linux__)
 
@@ -304,7 +304,11 @@ keep_cd_open( void )
 	if (fork())
 		exit(0);
 
+#if defined(O_NOFOLLOW)
+	if ((fd = open("/tmp/cd.lock", O_RDWR | O_CREAT | O_NOFOLLOW, 0666)) < 0)
+#else
 	if ((fd = open("/tmp/cd.lock", O_RDWR | O_CREAT, 0666)) < 0)
+#endif
 		exit(0);
 	fl.l_type = F_WRLCK;
 	fl.l_whence = 0;
