@@ -3,7 +3,7 @@
  *
  * kscd -- A simple CD player for the KDE project
  *
- * $Id: mgconfdlg.cpp,v 1.14 2001/09/21 06:23:30 dfoerste Exp $
+ * $Id: mgconfdlg.cpp,v 1.16 2002/07/03 13:22:36 binner Exp $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben wuebben@math.cornell.edu
  * Copyright (C) 2000 Dirk Frsterling <milliByte@gmx.de>
@@ -93,9 +93,9 @@ MGConfigDlg::MGConfigDlg(QWidget *parent,
 
   // Are Points Diamonds?
 
-  pointsAreDiamondsCB = new QCheckBox(this,"Points are Diamonds");
+  pointsAreDiamondsCB = new QCheckBox(this,"Points are diamonds");
   pointsAreDiamondsCB->setGeometry(20,150,160,30);
-  pointsAreDiamondsCB->setText(i18n("Points are Diamonds"));
+  pointsAreDiamondsCB->setText(i18n("Points are diamonds"));
   pointsAreDiamondsCB->setChecked(mgconfigdata.pointsAreDiamonds);
   connect(pointsAreDiamondsCB, SIGNAL(toggled(bool)),
 	  this, SLOT(pointsAreDiamonds_clicked(bool)));
