@@ -6,9 +6,13 @@
 
  */
 
-#include "../../lib/mpgplayer/mpgPlugin.h"
+#include "../../lib/decoder/mpgPlugin.h"
 #include "../../lib/util/timeWrapper.h"
 
+#include <iostream>
+
+using namespace std;
+
 int main(int argc, char** argv) {
 
 
@@ -65,6 +69,6 @@ int main(int argc, char** argv) {
   delete plugin;
   delete in;
   delete out;
-
+  return(0);
 }
  
