@@ -18,6 +18,8 @@
 #include "../yafcore/yaf_control.h"
 #include "../yafxplayer/inputDecoderYAF.h"
 
+#include <iostream>
+using namespace std;
 
 #include <math.h>
 
