@@ -10,6 +10,8 @@
 
  */
 
+#include <iostream>
+using namespace std;
 
 #include "cdromToc.h"
 #include "cdromRawAccess.h"
