@@ -56,7 +56,7 @@ class CDRomRawAccess {
   int isData();
 
  private:
-  int cdfile;
+  FILE* cdfile;
   int lOpen;
   int leof;
   int buflen;
