@@ -14,9 +14,9 @@
 #include "mpegAudioBitWindow.h"
 
 
+#include <iostream>
 
-
-
+using namespace std;
 
 int  MpegAudioBitWindow::getCanReadBits() {
   int p=bitindex>>3;
