@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "rgb2yuv16.h"
+#include <iostream>
 
 static unsigned short KEEPR[4] = { 63488, 63488, 63488, 63488 };
 unsigned short KEEPG[4] = {  2016,  2016,  2016,  2016 };
@@ -56,13 +57,13 @@ void dummyRGB2YUV16Bit() {
 #ifndef INTEL   
 void rgb2yuv16bit_mmx(unsigned char* ,unsigned char* ,unsigned char* ,
 		      unsigned char* ,int , int ) {
-  cout << "RGB->YUV not compiled with INTEL"<<endl;
+  std::cout << "RGB->YUV not compiled with INTEL" << std::endl;
   exit(0);
 }
 
 void rgb2yuv16bit_mmx_fast(unsigned char* ,unsigned char* ,unsigned char* ,
 		      unsigned char* ,int , int ) {
-  cout << "RGB->YUV not compiled with INTEL"<<endl;
+  std::cout << "RGB->YUV not compiled with INTEL" << std::endl;
   exit(0);
 }
 #endif
@@ -175,7 +176,7 @@ void rgb2yuv16bit_mmx422_row(unsigned char* rgb,
 	// 60%5 = TEMPV
 
 	__asm__ __volatile__ (
-		"rgb2yuv16_422:\n"
+		"1:\n"
 
 		// unpack hicolor ( pixel 1 - 4)
 		"movq      (%0),    %%mm0\n"
@@ -478,7 +479,7 @@ void rgb2yuv16bit_mmx422_row(unsigned char* rgb,
 		"add       $4,       %3\n"
 		
 		"sub       $8,       %4\n"
-  		"jnz       rgb2yuv16_422\n"
+  		"jnz       1b\n"
 
 		"emms\n"
 
@@ -494,7 +495,7 @@ void rgb2yuv16bit_mmx422_row_fast(unsigned char* rgb,
 				  unsigned char* cb, int pixel)
 {
 	__asm__ __volatile__ (
-		"rgb2yuv16_422_fast:\n"
+		"1:\n"
 
 		// unpack hicolor ( pixel 0 - 3)
 		"movq      (%0),    %%mm0\n"
@@ -615,7 +616,7 @@ void rgb2yuv16bit_mmx422_row_fast(unsigned char* rgb,
 		"add       $16,     %0\n"
 		
 		"sub       $8,      %4\n"
-		"jnz       rgb2yuv16_422_fast\n"
+		"jnz       1b\n"
 
 		"emms\n"
 
@@ -634,7 +635,7 @@ void rgb2y16bit_mmx_row(unsigned char* rgbSource,
 	// 44%3 = TEMPY
 	
 	__asm__ __volatile__ (
-		"rgb2y_16:\n"
+		"1:\n"
 
 		// unpack hicolor ( pixel 1 - 4)
 		"movq      (%0),    %%mm0\n"
@@ -849,7 +850,7 @@ void rgb2y16bit_mmx_row(unsigned char* rgbSource,
 		"add       $8,     %1\n"
 		
 		"sub       $8,     %2\n"
-  		"jnz       rgb2y_16\n"
+  		"jnz       1b\n"
 		"emms\n"
 
 		:
@@ -861,7 +862,7 @@ void rgb2y16bit_mmx_row(unsigned char* rgbSource,
 void rgb2y16bit_mmx_row_fast(unsigned char* rgb, unsigned char* lum, int pixel)
 {
 	__asm__ __volatile__ (
-        "rgb2y32_fast:\n"
+        "1:\n"
 		
 		// unpack hicolor ( pixel 1 - 4)
 		"movq      (%0),    %%mm0\n"
@@ -899,7 +900,7 @@ void rgb2y16bit_mmx_row_fast(unsigned char* rgb, unsigned char* lum, int pixel)
 		"add       $8,      %0\n"
 		
 		"sub       $4,      %2\n"
-		"jnz       rgb2y32_fast\n"
+		"jnz       1b\n"
 		
 		"emms\n"
 		
