@@ -13,11 +13,11 @@
 
 #ifndef __IMAGEDESKX11_H
 #define __IMAGEDESKX11_H
+#include <limits.h>
 #include "xinit.h"
 
 #include "../imageBase.h"
 
-
 #define VIDEO_XI_NONE         0x00 /* No access defined */
 #define VIDEO_XI_STANDARD     0x01 /* Use standard Xlib calls */
 #define VIDEO_XI_SHMSTD       0X02 /* Use Xlib shared memory extension */
@@ -44,14 +44,28 @@ class ImageDeskX11 : public ImageBase {
   Bool XShmPixmaps;
 
   XWindow* xWindow;
-  int ditherSize;
+  int imageMode;
   DitherWrapper* ditherWrapper;
 
+  int iOffsetX;
+  int iOffsetY;
+  int iWidth;
+  int iHeight;
+
+#ifdef X11_XVIDMODE
+  XF86VidModeModeInfo **vm_modelines;
+
+  int iOldMode;
+#endif
+
+  bool bZoom;
 
  public:
-  ImageDeskX11(XWindow* xWindow);
+  ImageDeskX11();
   ~ImageDeskX11();
 
+  void init(XWindow* xWindow, YUVPicture* pic = NULL);
+  
   int support();
 
   int openImage(int ditherSize);
@@ -64,6 +78,7 @@ class ImageDeskX11 : public ImageBase {
   int createImage(int createType,int size);
   int destroyImage();
 
+  bool switchMode(int width, int height, bool zoom);
 
 };
 
