@@ -10,17 +10,18 @@
 
  */
 
+#include <queue>
+
+#include <connect.h>
+
 #include "decoderBaseObject_impl.h"
 #include "../mpeglib/lib/decoder/decoderPlugin.h"
-#include "../mpeglib/lib/decoder/splayPlugin.h"
 #include "debug.h"
 
 // define this to run the playobject without the
 // arts backend. (usefull to check if a bug is in arts or mpeglib)
 //#define _STRIP_ZERO
 
-using namespace Arts;
-
 static int instanceCnt=0;
 
 DecoderBaseObject_impl::DecoderBaseObject_impl()
@@ -29,19 +30,22 @@ DecoderBaseObject_impl::DecoderBaseObject_impl()
 
   flpos=0.0;
   _blocking = false;
+
 #ifdef _STRIP_ZERO
   outputStream=NULL;
 #else
-  outputStream=new ArtsOutputStream(NULL);
+  m_outputStream=new ArtsOutputStream(NULL);
   arts_debug("outputStream created");
   decoderPlugin=NULL;
 #endif
   startTime=0.0;
-  inputStream=NULL;
+  m_inputStream=NULL;
   setStreamState(_THREADSTATE_INIT);
-  _state=posIdle;
+  _state=Arts::posIdle;
   instance=instanceCnt;
   instanceCnt++;
+
+  m_packetQueue = new std::queue<DataPacket<mcopbyte>*>;
 }
 
 DecoderBaseObject_impl::~DecoderBaseObject_impl() {
@@ -53,11 +57,16 @@ DecoderBaseObject_impl::~DecoderBaseObject_impl() {
     delete decoderPlugin;
     decoderPlugin=NULL;
   }
-  if (outputStream != NULL) {
+  if (m_outputStream != NULL) {
     arts_debug("delete outputStream");
-    delete outputStream;
-    outputStream=NULL;
+    delete m_outputStream;
+    m_outputStream=NULL;
   }
+
+  if (m_streaming)
+      m_artsInputStream.streamEnd();
+
+  delete m_packetQueue;
 }
 
 
@@ -74,10 +83,12 @@ DecoderPlugin* DecoderBaseObject_impl::createPlugin() {
 
 
 bool DecoderBaseObject_impl::loadMedia(const string &filename) {
+  arts_debug("loadMedia");
   int back=true;
 
+  m_streaming = false;
 
-  if ( inputStream != NULL ) {
+  if ( m_inputStream != NULL ) {
     arts_fatal("remove resources first with a call to: halt()");
   }
   if (decoderPlugin == NULL) {
@@ -99,25 +110,94 @@ bool DecoderBaseObject_impl::loadMedia(const string &filename) {
   return true;
 #endif
 
-  inputStream=createInputStream(filename.c_str());
+  m_inputStream=createInputStream(filename.c_str());
 
   // the plugin does not open the stream!
   // we do it.
-  back=inputStream->open((char*)filename.c_str());
+  back=m_inputStream->open((char*)filename.c_str());
   setStreamState(_THREADSTATE_OPENED);
 
   // we are still in posIdle here
-  outputStream->audioOpen();
+  m_outputStream->audioOpen();
 
   // watch the order!
-  decoderPlugin->setOutputPlugin(outputStream);
-  decoderPlugin->setInputPlugin(inputStream);
-
+  decoderPlugin->setOutputPlugin(m_outputStream);
+  decoderPlugin->setInputPlugin(m_inputStream);
 
   return back;
 }
 
+#define INPUT_BUFFER_SIZE 32768
 
+bool DecoderBaseObject_impl::streamMedia(Arts::InputStream instream) {
+  arts_debug("DecoderBaseObject_impl::streamMedia -s");
+  
+  bool back = true;
+  
+  if (m_inputStream != NULL) {
+    arts_fatal("resource in use, call halt() first");
+  }
+  if (decoderPlugin == NULL) {
+    decoderPlugin = createPlugin();
+    if (doFloat())
+      decoderPlugin->config("dofloat", 0, 0);
+    // streaming, don't know the length
+    decoderPlugin->config("-c", 0, 0);
+  }
+  
+  flpos = 0.0;
+  startTime = 0.0;
+  m_streaming = true;
+  lastAudioBufferSize = -1;
+  
+  m_artsInputStream = instream;
+  
+  m_inputStream = new BufferInputStream(INPUT_BUFFER_SIZE, 4096, (char*)"InputStream");
+  m_inputStream->open((char*)"InputStream");
+  
+  // connect the stream now
+  Arts::StreamPlayObject self = Arts::StreamPlayObject::_from_base(_copy());
+  connect(m_artsInputStream, "outdata", self);
+  
+  setStreamState(_THREADSTATE_OPENED);
+  
+  m_outputStream->audioOpen();
+  
+  decoderPlugin->setOutputPlugin(m_outputStream);
+  decoderPlugin->setInputPlugin(m_inputStream);
+  
+  arts_debug("DecoderBaseObject_impl::streamMedia -e");
+  
+  return back;
+}
+
+void DecoderBaseObject_impl::process_indata(DataPacket<mcopbyte> *inpacket) {
+
+  m_packetQueue->push(inpacket);
+  processQueue();
+}
+
+void DecoderBaseObject_impl::processQueue() {
+
+  // early exit if no packets in the queue
+  if (m_packetQueue->empty())
+    return;
+  
+  // see how much space we have in the stream
+  BufferInputStream* stream = (BufferInputStream*)m_inputStream;
+  
+  int length = stream->getByteLength();
+  int freeSpace = INPUT_BUFFER_SIZE - length;
+  
+  DataPacket<mcopbyte> *inpacket;
+  inpacket = m_packetQueue->front();
+  
+  if (freeSpace >= inpacket->size) {
+    stream->write((char*)inpacket->contents, inpacket->size, 0);
+    m_packetQueue->pop();
+    inpacket->processed();
+  }
+}
 
 string DecoderBaseObject_impl::description() {
   arts_debug("description");
@@ -141,7 +221,7 @@ poTime DecoderBaseObject_impl::currentTime() {
 #ifdef _STRIP_ZERO
   return time;
 #endif
-  AudioTime* audioTime=outputStream->getAudioTime();
+  AudioTime* audioTime=m_outputStream->getAudioTime();
   float currentTime=audioTime->getTime()+(float)startTime;
   time.seconds=(long)(currentTime);
   time.ms=(long) (1000.0*(currentTime-(float)time.seconds));
@@ -170,10 +250,10 @@ poCapabilities DecoderBaseObject_impl::capabilities() {
   PluginInfo* pluginInfo=decoderPlugin->getPluginInfo();
   long len=pluginInfo->getLength();
   if (len == 0) {
-    return capPause;  /* no seek supported */
+    return Arts::capPause;  /* no seek supported */
   }
   // seek and pause supported
-  return (poCapabilities)(capSeek | capPause);
+  return (poCapabilities)(Arts::capSeek | Arts::capPause);
 }
 
 string DecoderBaseObject_impl::mediaName() {
@@ -190,13 +270,13 @@ poState DecoderBaseObject_impl::state() {
 void DecoderBaseObject_impl::play() {
   arts_debug("play: %d", (int)streamState);
   if (streamState == _THREADSTATE_OPENED) {
-    decoderPlugin->play();
+      decoderPlugin->play();
   } else {
-    Command cmd(_COMMAND_PLAY);
-    decoderPlugin->insertAsyncCommand(&cmd);
+      Command cmd(_COMMAND_PLAY);
+      decoderPlugin->insertAsyncCommand(&cmd);
   }
   setStreamState(_THREADSTATE_PLAYING);
-  _state = posPlaying;
+  _state = Arts::posPlaying;
 }
 
 void DecoderBaseObject_impl::seek(const class poTime& seekTime) {
@@ -214,11 +294,11 @@ void DecoderBaseObject_impl::seek(const class poTime& seekTime) {
 
   // if the thread blocks on the artsOutputstream: kick him out
   // the next command will the the seek command
-  outputStream->audioClose();
+  m_outputStream->audioClose();
 
 
   // thread blocking allowed
-  outputStream->audioOpen();
+  m_outputStream->audioOpen();
   arts_debug("************ reopen");
   // now set a new startTime
   startTime=sec;
@@ -226,7 +306,7 @@ void DecoderBaseObject_impl::seek(const class poTime& seekTime) {
 
 void DecoderBaseObject_impl::pause() {
   arts_debug("pause");
-  _state = posPaused;
+  _state = Arts::posPaused;
   Command cmd(_COMMAND_PAUSE);
   decoderPlugin->insertAsyncCommand(&cmd);
 }
@@ -241,7 +321,7 @@ void DecoderBaseObject_impl::halt() {
    */
 
   arts_debug("halt");
-  _state=posIdle;
+  _state=Arts::posIdle;
   shudownPlugins();
 }
 
@@ -255,13 +335,14 @@ void DecoderBaseObject_impl::streamInit() {
 
 
 void DecoderBaseObject_impl::streamStart() {
+    arts_debug("DecoderBaseObject_impl::streamStart");
 }
 
 int DecoderBaseObject_impl::fillArts(unsigned long samples,
 				     float* left , float* right) {
   unsigned long haveSamples = 0;
 
-  AudioTime* audioTime=outputStream->getAudioTime();
+  AudioTime* audioTime=m_outputStream->getAudioTime();
   int wav_samplingRate=audioTime->getSpeed();
   int wav_sampleWidth=audioTime->getSampleSize();
   int wav_channelCount=audioTime->getStereo()+1;
@@ -269,7 +350,10 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
   if(doFloat()) wav_sampleWidth = sizeof(float)*8;
 
   // here seems to be an error, I have clicks sometimes in the stream
-  int byteMultiplikator=(wav_sampleWidth/8)*wav_channelCount;
+  //int byteMultiplikator=(wav_sampleWidth/8)*wav_channelCount;
+
+  // maybe first multiply, then divide?
+  int byteMultiplikator = wav_channelCount * wav_sampleWidth / 8;
 
   char* buffer;
   int hasBytes = 0;
@@ -277,7 +361,7 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
   int bufferSize=getBufferSize();
   if (bufferSize != lastAudioBufferSize) {
     lastAudioBufferSize=bufferSize;
-    outputStream->setAudioBufferSize(bufferSize);
+    m_outputStream->setAudioBufferSize(bufferSize);
   }
 
   /* difference between the sampling rates in percent */
@@ -289,9 +373,9 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
    * 1. decoder -> float rendering
    * 2. no resampling (i.e. artsd running @ 44100 Hz, playing an 44100 Hz mp3)
    */
-  if(_state == posPlaying && doFloat() && diff < 0.0005) {
+  if(_state == Arts::posPlaying && doFloat() && diff < 0.0005) {
     wantBytes = sizeof(float) * wav_channelCount * samples;
-    hasBytes = outputStream->read(&buffer,wantBytes);
+    hasBytes = m_outputStream->read(&buffer,wantBytes);
     float *flptr = (float *)buffer;
 
     if(wav_channelCount == 1)
@@ -311,9 +395,9 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
 	haveSamples++;
       }
     }
-    outputStream->forwardReadPtr(haveSamples*sizeof(float)*wav_channelCount);
+    m_outputStream->forwardReadPtr(haveSamples*sizeof(float)*wav_channelCount);
   }
-  else if(_state == posPlaying) {
+  else if(_state == Arts::posPlaying) {
     //
     // since the samplingrate of the MP3 and the samplingrate of the output
     // device (soundcard) are not necessarily the same, it's a bit tricky
@@ -330,12 +414,12 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
 
     // convert that into bytes and try to read that many bytes
     wantBytes=(int) (wantWavSamples*byteMultiplikator);
-    hasBytes=outputStream->read(&buffer,wantBytes);
+    hasBytes=m_outputStream->read(&buffer,wantBytes);
 
-    int format = doFloat()?uni_convert_float_ne:wav_sampleWidth;
+    int format = doFloat()?Arts::uni_convert_float_ne:wav_sampleWidth;
 
     // convert those bytes into the suitable output form
-    haveSamples = uni_convert_stereo_2float(samples, (unsigned char *)buffer,
+    haveSamples = Arts::uni_convert_stereo_2float(samples, (unsigned char *)buffer,
 					    hasBytes, wav_channelCount,
 					    format,
 					    left,right,speed,flpos);
@@ -354,7 +438,7 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
 
     flpos = flpos - floor(flpos);
 
-    outputStream->forwardReadPtr(forward);
+    m_outputStream->forwardReadPtr(forward);
   }
 
   if(haveSamples != samples) {
@@ -374,26 +458,41 @@ void DecoderBaseObject_impl::calculateBlock(unsigned long samples,
 
 #ifndef _STRIP_ZERO
 
-  int audioState=outputStream->waitStreamState(_OUTPUT_WAIT_METHOD_POLL,
+  int audioState=m_outputStream->waitStreamState(_OUTPUT_WAIT_METHOD_POLL,
 					       _STREAM_MASK_ALL,
 					       _STREAMTYPE_AUDIO);
+
   if (audioState & _STREAM_MASK_IS_INIT) {
     // now check if we already have enough data
     int lenough=false;
     if (audioState & _STREAM_MASK_IS_EOF) {
-      if(_state == posPlaying) {
+      if(_state == Arts::posPlaying) {
 	arts_debug("eof got in arts********** END");
-	_state = posIdle;
+	_state = Arts::posIdle;
       }
-
+      
       lenough=true;
     }
-    if (outputStream->getBufferFillgrade() >= 0) {
+    if (m_outputStream->getBufferFillgrade() >= 4096) {
       lenough=true;
     }
-    if ( ((lenough) || _blocking) && (_state == posPlaying) ) {
-      fillArts(samples,left,right);
-      return;
+    
+    if (_state == Arts::posPlaying) {
+      if (m_streaming) {
+	// produce more data
+	processQueue();
+	// check for stream end
+	if ( m_inputStream->getByteLength() == 0 ) {
+	  if ( m_artsInputStream.eof() ) {
+	    m_inputStream->close();
+	    m_artsInputStream.streamEnd();
+	  }
+	}
+      }
+      if (lenough || _blocking) {
+	fillArts(samples, left, right);
+	return;
+      }
     }
   }
 #endif
@@ -406,9 +505,11 @@ void DecoderBaseObject_impl::calculateBlock(unsigned long samples,
 }
 
 void DecoderBaseObject_impl::streamEnd() {
+  arts_debug("streamEnd");
 #ifdef _STRIP_ZERO
   return;
 #endif
+  
   halt();
 }
 
@@ -419,9 +520,9 @@ int DecoderBaseObject_impl::getBufferSize() {
   float fragmentCount;
   float channels;
   float sampleSize;
-  fragmentSize=AudioSubSystem::the()->fragmentSize();
-  fragmentCount=AudioSubSystem::the()->fragmentCount();
-  channels=AudioSubSystem::the()->channels();
+  fragmentSize=Arts::AudioSubSystem::the()->fragmentSize();
+  fragmentCount=Arts::AudioSubSystem::the()->fragmentCount();
+  channels=Arts::AudioSubSystem::the()->channels();
   sampleSize=16.0/8.0;
 
   hardwareBuffer=fragmentSize*fragmentCount;
@@ -432,6 +533,7 @@ int DecoderBaseObject_impl::getBufferSize() {
 
 
 void DecoderBaseObject_impl::shudownPlugins() {
+  arts_debug("shudownPlugins -s");
   /**
      The order here is important.
      First we close the audio so that the thread never blocks
@@ -443,11 +545,12 @@ void DecoderBaseObject_impl::shudownPlugins() {
   */
 
   // this should theoretically be faster
-  Command cmd(_COMMAND_CLOSE);
-  decoderPlugin->insertAsyncCommand(&cmd);
-
-  if (outputStream != NULL) {
-    outputStream->audioClose();
+  if (decoderPlugin != NULL) {
+    Command cmd(_COMMAND_CLOSE);
+    decoderPlugin->insertAsyncCommand(&cmd);
+  }
+  if (m_outputStream != NULL) {
+    m_outputStream->audioClose();
   }
 
   // very likely the thread already is closed
@@ -456,12 +559,17 @@ void DecoderBaseObject_impl::shudownPlugins() {
     decoderPlugin->close();
   }
 
-
-  if (inputStream != NULL) {
-    delete inputStream;
-    inputStream=NULL;
+  if (m_inputStream != NULL) {
+    delete m_inputStream;
+    m_inputStream=NULL;
   }
+  
+  if (m_streaming)
+    m_artsInputStream.streamEnd();
+
   setStreamState(_THREADSTATE_CLOSED);
+
+  arts_debug("shudownPlugins -e");
 }
 
 void DecoderBaseObject_impl::setStreamState(int state) {
