@@ -1,11 +1,13 @@
+// $Id: engine.cpp,v 1.89 2002/10/27 20:59:35 charles Exp $
+
 #include <noatun/engine.h>
 #include <noatun/equalizer.h>
 #include <noatun/player.h>
 #include <noatun/plugin.h>
 #include <noatun/effects.h>
 
+#include <kdebug.h>
 #include <string.h>
-#include <iostream.h>
 
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -40,7 +42,7 @@ static Arts::PlayObject nullPO() { return Arts::PlayObject::null(); }
 #elif defined(__linux__)
 #include <sys/soundcard.h>
 #elif defined(__FreeBSD__)
-#include "machine/soundcard.h"
+#include <sys/soundcard.h>
 #elif defined(__NetBSD__)
 #include <soundcard.h>
 #elif defined(___SOMETHING_UNKNOWN__)
@@ -210,7 +212,7 @@ public:
 		visStack=Noatun::StereoEffectStack::null();
 	}
 	
-	KPlayObject *playobj;
+	KDE::PlayObject *playobj;
 	Arts::SoundServerV2 server;
 	Arts::Synth_AMAN_PLAY amanPlay;
 
@@ -240,7 +242,7 @@ Noatun::StereoEffectStack *Engine::globalEffectStack() const  { return &d->globa
 Noatun::Equalizer *Engine::equalizer() const { return &d->equalizer; }
 Noatun::Session *Engine::session() const { return &d->session; }
 
-Engine::Engine(QObject *parent) : QObject(parent), mPlay(false)
+Engine::Engine(QObject *parent) : QObject(parent, "Engine"), mPlay(false)
 {
 	d=new EnginePrivate;
 	// Connect to aRts
@@ -282,15 +284,15 @@ bool Engine::open(const PlaylistItem &file)
 		return false;
 	}
 
-	KPlayObjectFactory factory(d->server);
-	
-//	cerr << QFile::encodeName(file.file()).data() << file.mimetype() << file.isProperty("stream_") << endl;
+	KDE::PlayObjectFactory factory(d->server);
 	
 	factory.setAllowStreaming(file.isProperty("stream_"));
 
 	if (file.isProperty("stream_"))
 	{
-		d->playobj=factory.createPlayObject(file.property("stream_"), file.mimetype(), false);
+		// let the factory decide
+		// d->playobj=factory.createPlayObject(file.property("stream_"), file.mimetype(), false);
+		d->playobj=factory.createPlayObject(file.property("stream_"), false);
 	}
 	else
 	{
@@ -306,17 +308,33 @@ bool Engine::open(const PlaylistItem &file)
 		return false;
 	}
 
-	d->playobj->object()._node()->start();
-	
-	// TODO: check for existence of left & right streams
-	Arts::connect(d->playobj->object(),"left",d->globalEffectStack,"inleft");
-	Arts::connect(d->playobj->object(),"right",d->globalEffectStack,"inright");
+	if ( !d->playobj->object().isNull() )
+	{
+		connectPlayObject();
+	}
+	else
+	{
+		connect( d->playobj, SIGNAL( playObjectCreated() ), this, SLOT( connectPlayObject() ) );
+	}
+
 	if (mPlay)
 		d->playobj->play();
 
 	return true;
 }
 
+void Engine::connectPlayObject()
+{
+	if (d->playobj->object().isNull()) return;
+	d->playobj->object()._node()->start();
+
+	// TODO: check for existence of left & right streams
+	Arts::connect(d->playobj->object(),"left",d->globalEffectStack,"inleft");
+	Arts::connect(d->playobj->object(),"right",d->globalEffectStack,"inright");
+
+	emit aboutToPlay();
+}
+
 bool Engine::play()
 {
 	if (!mPlay) return true;
@@ -356,9 +374,6 @@ void Engine::seek(int msec) // pass time in msecs
 int Engine::position()
 {
 	if(!d->playobj) return -1;
-
-	if (! (d->playobj->capabilities() & Arts::capSeek))
-		return -1;
 	
 	Arts::poTime time(d->playobj->currentTime());
 	return (int)(time.ms + (time.seconds*1000)); // return position in milliseconds
@@ -407,6 +422,7 @@ bool Engine::initArts()
 	if ( d->server.isNull() || d->server.error()  )
 	{
 		d->server = Arts::Reference("global:Arts_SoundServerV2");
+		int volume = d->volumeControl ? d->volumeControl->volume() : 100;
 		delete d->volumeControl;
 		d->volumeControl=0;
 
@@ -481,12 +497,12 @@ bool Engine::initArts()
 				);
 			if (d->session.isNull())
 			{
-				cerr << "Couldn't instanciate artsobject Noatun::Session. "
-				     << "(This is normally caused by a broken package or "
-				     << "compiling kdemultimedia in a --prefix different "
-				     << "from arts.  It may also be from two conflicting "
-					 << "packages, so uninstall every arts/artsd package "
-					 << "you have installed and try againe." << endl;
+				kdWarning() << "Couldn't instanciate artsobject Noatun::Session. "
+				            << "(This is normally caused by a broken package or "
+				            << "compiling kdemultimedia in a --prefix different "
+				            << "from arts.  It may also be from two conflicting "
+					    << "packages, so uninstall every arts/artsd package "
+					    << "you have installed and try againe." << endl;
 				
 			}
 			
@@ -521,6 +537,7 @@ bool Engine::initArts()
 			
 			d->globalEffectStack.insertBottom(d->visStack, "Visualization Stack");
 			d->volumeControl=VolumeControls::volumeControl(this);
+			d->volumeControl->setVolume(volume);
 		}
 		else
 		{
