@@ -1,7 +1,7 @@
 /*
   Winamp Skin
   Copyright (C) 1999  Martin Vogt
-  Copyright (C) 2001  Ryan Cumming
+  Copyright (C) 2001-2002  Ryan Cumming
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include <kiconloader.h>
 #include <khelpmenu.h>
 #include <kpopupmenu.h>
+#include <kurldrag.h>
 #include <kstdaction.h>
 #include <kaction.h>
 #include <qdragobject.h>
@@ -49,6 +50,9 @@
 
 #include "waStatus.h"
 
+#include "waSkinManager.h"
+#include "waSkinModel.h"
+
 #include "guiSpectrumAnalyser.h"
 #include "fileInfo.h"
 
@@ -64,7 +68,10 @@ WaSkin::WaSkin() : UserInterface()
 
     _waskin_instance = this;
 
+    // Our really low-level render-y sort of stuff
     waSkinModel = new WaSkinModel();
+    // Skin management stuff
+    waSkinManager = new WaSkinManager();
 
     createHighLevelElements();
     createButtons();
@@ -134,11 +141,7 @@ WaSkin::~WaSkin()
 
 void WaSkin::loadSkin(QString newSkinDir)
 {
-    QStringList skins =
-        KGlobal::dirs()->findDirs("data", "noatun/skins/winamp/" + newSkinDir);
-
-    waSkinModel->load(skins[0]);
-    skinDir = skins[0];
+    waSkinManager->loadSkin(newSkinDir);
 
     setMinimumSize(sizeHint());
 
@@ -523,11 +526,12 @@ void WaSkin::dragEnterEvent(QDragEnterEvent * event)
 
 void WaSkin::dropEvent(QDropEvent * event)
 {
-    QStrList uri;
-    if (QUriDrag::decode(event, uri)) {
-        for (char *file = uri.first(); file != 0; file = uri.next())
-            napp->player()->openFile(KURL(file), false);
-    }
+	KURL::List uri;
+	if (KURLDrag::decode(event, uri))
+	{
+		for (KURL::List::Iterator i = uri.begin(); i != uri.end(); ++i)
+			napp->player()->openFile(*i, false);
+	}
 }
 
 void WaSkin::balanceSliderPressed()
